@@ -20,7 +20,6 @@ extern "C"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-/*#include <malloc.h>*/
 
 #include "ajassert.h"
 #include "ajdefine.h"
@@ -74,6 +73,9 @@ extern "C"
 #include "ajvector.h"
 #include "ajdom.h"
 #include "ajsql.h"
+#include "ajobo.h"
+#include "ajtax.h"
+#include "ajresource.h"
     
 #endif
 
