@@ -124,6 +124,8 @@ float ajRoundFloat(float a, ajint nbits)
 }
 
 
+
+
 /* @obsolete ajRoundF
 ** @rename ajRoundFloat
 */
@@ -135,12 +137,13 @@ __deprecated float ajRoundF(float a, ajint nbits)
 
 
 
+
 /* @func ajCvtRecToPol ********************************************************
 **
-** Converts cartesian co-ordinates to polar
+** Converts Cartesian coordinates to polar
 **
-** @param [r] x [float] X co-ordinate
-** @param [r] y [float] Y co-ordinate
+** @param [r] x [float] X coordinate
+** @param [r] y [float] Y coordinate
 ** @param [w] radius [float*] Radius
 ** @param [w] angle [float*] Angle
 ** @return [void]
@@ -154,6 +157,9 @@ void ajCvtRecToPol(float x, float y, float *radius, float *angle)
     return;
 }
 
+
+
+
 /* @obsolete ajRecToPol
 ** @rename ajCvtRecToPol
 */
@@ -166,14 +172,15 @@ __deprecated void ajRecToPol(float x, float y, float *radius, float *angle)
 
 
 
+
 /* @func ajCvtPolToRec  *******************************************************
 **
-** Converts polar co-ordinates to cartesian
+** Converts polar coordinates to Cartesian
 **
 ** @param [r] radius [float] Radius
 ** @param [r] angle [float] Angle
-** @param [w] x [float*] X co-ordinate
-** @param [w] y [float*] Y co-ordinate
+** @param [w] x [float*] X coordinate
+** @param [w] y [float*] Y coordinate
 ** @return [void]
 ******************************************************************************/
 
@@ -185,6 +192,9 @@ void ajCvtPolToRec(float radius, float angle, float *x, float *y)
     return;
 }
 
+
+
+
 /* @obsolete ajPolToRec
 ** @rename ajCvtPolToRec
 */
@@ -213,6 +223,8 @@ float ajCvtDegToRad(float degrees)
 }
 
 
+
+
 /* @obsolete ajDegToRad
 ** @rename ajCvtDegToRad
 */
@@ -239,6 +251,8 @@ float ajCvtRadToDeg(float radians)
 }
 
 
+
+
 /* @obsolete ajRadToDeg
 ** @rename ajCvtRadToDeg
 */
@@ -268,6 +282,8 @@ double ajCvtGaussToProb(float mean, float sd, float score)
 }
 
 
+
+
 /* @obsolete ajGaussProb
 ** @rename ajCvtGaussToProb
 */
@@ -280,6 +296,7 @@ __deprecated double ajGaussProb(float mean, float sd, float score)
 
 
 
+
 /* @func ajMathGmean **********************************************************
 **
 ** Calculate a geometric mean
@@ -300,6 +317,8 @@ float ajMathGmean(const float *s, ajint n)
 }
 
 
+
+
 /* @obsolete ajGeoMean
 ** @rename ajMathGmean
 */
@@ -310,6 +329,8 @@ __deprecated float ajGeoMean(const float *s, ajint n)
 }
 
 
+
+
 /* @func ajMathModulo *********************************************************
 **
 ** Modulo always returning positive number
@@ -332,6 +353,8 @@ ajint ajMathModulo(ajint a, ajint b)
 }
 
 
+
+
 /* @obsolete ajPosMod
 ** @rename ajMathModulo
 */
@@ -342,6 +365,8 @@ __deprecated ajint ajPosMod(ajint a, ajint b)
 }
 
 
+
+
 /* @func ajRandomSeed *********************************************************
 **
 ** Seed for the ajRandomDouble routine
@@ -396,7 +421,7 @@ void ajRandomSeed(void)
 	gettimeofday(&tv,NULL);
 	seed = (tv.tv_usec % 9999)+1;
 #else
-	/* Needs looking at to try to get usec resolution */
+	/* Needs looking at to try to get micro second resolution */
 	seed = (ajint) ((time(0) % 9999) + 1);
 #endif
     }
@@ -542,7 +567,7 @@ double ajRandomDouble(void)
         y = 37.0*aj_rand_other+offset;
         aj_rand_other = y-floor(y);
     }
-    while(!aj_rand_other);
+    while(E_FPZERO(aj_rand_other,U_DEPS));
 
     if((x = x/AjRandomXmod+aj_rand_other) >= 1.0)
 	x -= 1.0;
@@ -564,6 +589,8 @@ __deprecated double ajRandomNumberD(void)
 }
 
 
+
+
 /* @funcstatic spcrc64calctab *************************************************
 **
 ** Initialise the crc table.
@@ -596,6 +623,9 @@ static void spcrc64calctab(unsigned long long *crctab)
     }
 }
 
+
+
+
 /* @func ajMathCrc32 **********************************************************
 **
 ** Calculates the SwissProt style CRC32 checksum for a protein sequence.
@@ -642,6 +672,8 @@ ajuint ajSp32Crc(const AjPStr seq)
 }
 
 
+
+
 /* @funcstatic spcrc32gen *****************************************************
 **
 ** Generates data for a CRC32 calculation in a static data structure.
@@ -724,6 +756,7 @@ unsigned long long ajSp64Crc(const AjPStr thys)
 
 
 
+
 /* @func ajCvtSposToPos *******************************************************
 **
 ** Converts a string position into a true position. If ipos is negative,
@@ -740,6 +773,9 @@ ajuint ajCvtSposToPos(ajuint len, ajint ipos)
     return ajCvtSposToPosStart(len, 0, ipos);
 }
 
+
+
+
 /* @obsolete ajMathPos
 ** @rename ajCvtSposToPos
 */
@@ -750,6 +786,8 @@ __deprecated ajuint ajMathPos(ajuint len, ajint ipos)
 }
 
 
+
+
 /* @func ajCvtSposToPosStart **************************************************
 **
 ** Converts a position into a true position. If ipos is negative,
@@ -787,6 +825,8 @@ ajuint ajCvtSposToPosStart(ajuint len, ajuint imin, ajint ipos)
 }
 
 
+
+
 /* @obsolete ajMathPosI
 ** @rename ajCvtSposToPosStart
 */
@@ -797,6 +837,8 @@ __deprecated ajuint ajMathPosI(ajuint len, ajuint imin, ajint ipos)
 }
 
 
+
+
 /* @func ajNumLengthDouble ****************************************************
 **
 ** Returns the length of a number written as an integer
