@@ -130,6 +130,8 @@ AjPRange ajRangeNewFilename(const AjPStr name)
 }
 
 
+
+
 /* @obsolete ajRangeFile
 ** @rename ajRangeNewFilename
 */
@@ -140,6 +142,8 @@ __deprecated AjPRange ajRangeFile(const AjPStr name)
 }
 
 
+
+
 /* @func ajRangeNewFilenameLimits **********************************************
 **
 ** Load a range object from a file
@@ -339,6 +343,7 @@ AjPRange ajRangeNewFilenameLimits(const AjPStr name, ajuint imin, ajuint imax,
 
 
 
+
 /* @obsolete ajRangeFileLimits
 ** @rename ajRangeNewFilenameLimits
 */
@@ -394,6 +399,8 @@ AjPRange ajRangeNewRange(const AjPRange src)
 }
 
 
+
+
 /* @obsolete ajRangeCopy
 ** @rename ajRangeNewRange
 */
@@ -423,6 +430,8 @@ AjPRange ajRangeNewString(const AjPStr str)
 }
 
 
+
+
 /* @obsolete ajRangeGet
 ** @rename ajRangeNewString
 */
@@ -433,6 +442,8 @@ __deprecated AjPRange ajRangeGet(const AjPStr str)
 }
 
 
+
+
 /* @func ajRangeNewStringLimits ***********************************************
 **
 ** Create a range object from a string
@@ -533,7 +544,7 @@ AjPRange ajRangeNewStringLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    cp = ajStrGetPtr(c2);
 	    p = ajSysFuncStrtok(cp, nondigit);
 
-	    if(!sscanf(p,"%d",&f))
+	    if(!sscanf(p,"%u",&f))
 	    {
 		ajWarn("Bad range value [%s]",p);
 		ajRangeDel(&ret);
@@ -543,7 +554,7 @@ AjPRange ajRangeNewStringLimits(const AjPStr str, ajuint imin, ajuint imax,
 
 	    p = ajSysFuncStrtok(NULL, nondigit);
 
-	    if(!sscanf(p,"%d",&t))
+	    if(!sscanf(p,"%u",&t))
 	    {
 		ajWarn("Bad range value [%s]",p);
 		ajRangeDel(&ret);
@@ -582,7 +593,7 @@ AjPRange ajRangeNewStringLimits(const AjPStr str, ajuint imin, ajuint imax,
 	    {
 		p = ajSysFuncStrtok(NULL, nondigit);
 
-		if(!sscanf(p,"%d",&f))
+		if(!sscanf(p,"%u",&f))
 		{
 		    ajWarn("Bad range value [%s]",p);
 		    ajRangeDel(&ret);
@@ -592,7 +603,7 @@ AjPRange ajRangeNewStringLimits(const AjPStr str, ajuint imin, ajuint imax,
 
 		p = ajSysFuncStrtok(NULL, nondigit);
 
-		if(!sscanf(p,"%d",&t))
+		if(!sscanf(p,"%u",&t))
 		{
 		    ajWarn("Bad range value [%s]",p);
 		    ajRangeDel(&ret);
@@ -673,6 +684,8 @@ AjPRange ajRangeNewStringLimits(const AjPStr str, ajuint imin, ajuint imax,
 }
 
 
+
+
 /* @obsolete ajRangeGetLimits
 ** @rename ajRangeNewStringLimits
 */
@@ -685,6 +698,8 @@ __deprecated AjPRange ajRangeGetLimits(const AjPStr str,
 }
 
 
+
+
 /* @section Range Destructors ************************************************
 **
 ** Default destructor for AJAX range objects
@@ -756,6 +771,7 @@ ajuint ajRangeGetSize(const AjPRange thys)
 
 
 
+
 /* @obsolete ajRangeNumber
 ** @rename ajRangeGetSize
 */
@@ -766,12 +782,14 @@ __deprecated ajuint ajRangeNumber(const AjPRange thys)
 }
 
 
+
+
 /* @func ajRangeElementGetText *************************************************
 **
 ** Return (as parameters) text value of a range element
 **
 ** The text value of a range is any non-digit after the pair of range numbers
-** eg. in a pair of range '10-20 potential exon 50-60 repeat'
+** e.g. in a pair of range '10-20 potential exon 50-60 repeat'
 ** the text values of the two ranges are: 'potential exon' and 'repeat'
 **
 ** @param [r] thys [const AjPRange] range object
@@ -804,6 +822,8 @@ AjBool ajRangeText(const AjPRange thys, ajuint element, AjPStr * text)
 }
 
 
+
+
 /* @func ajRangeElementGetValues ***********************************************
 **
 ** Return (as parameters) start and end values in a range
@@ -849,9 +869,11 @@ AjBool ajRangeValues(const AjPRange thys, ajuint element,
 }
 
 
+
+
 /* @func ajRangeElementSet *****************************************************
 **
-** Set the values of a start and end in a (preexisting) range element
+** Set the values of a start and end in a (pre-existing) range element
 **
 ** @param [w] thys [AjPRange] range object
 ** @param [r] element [ajuint] range element (0 to n-1)
@@ -877,6 +899,8 @@ AjBool ajRangeElementSet(AjPRange thys, ajuint element,
 }
 
 
+
+
 /* @obsolete ajRangeChange
 ** @rename ajRangeElementSet
 */
@@ -887,6 +911,8 @@ __deprecated AjBool ajRangeChange(AjPRange thys, ajuint element,
 }
 
 
+
+
 /* @func ajRangeSetOffset *****************************************************
 **
 ** Sets the range values offset relative to the Begin value.
@@ -944,6 +970,7 @@ __deprecated AjBool ajRangeBegin(AjPRange thys, ajuint begin)
 
 
 
+
 /* @func ajRangeSeqExtractList ************************************************
 **
 ** Extract the range from a sequence and place the resulting text in a
@@ -1806,6 +1833,7 @@ ajuint ajRangeElementTypeOverlap(const AjPRange thys, ajuint element,
 
 
 
+
 /* @obsolete ajRangeOverlapSingle
 ** @remove Use ajRangeElementTypeOverlap
 */
@@ -1850,6 +1878,7 @@ __deprecated ajuint ajRangeOverlapSingle(ajuint start, ajuint end,
 
 
 
+
 /* @func ajRangeCountOverlaps **************************************************
 **
 ** Detect overlaps of a set of ranges to a region of a sequence
@@ -1882,6 +1911,7 @@ ajuint ajRangeCountOverlaps(const AjPRange thys, ajuint pos, ajuint length)
 
 
 
+
 /* @obsolete ajRangeOverlaps
 ** @rename ajRangeCountOverlaps
 */
@@ -1933,6 +1963,7 @@ AjBool ajRangeIsOrdered(const AjPRange thys)
 
 
 
+
 /* @obsolete ajRangeOrdered
 ** @rename ajRangeIsOrdered
 */
@@ -1944,6 +1975,7 @@ __deprecated AjBool ajRangeOrdered(const AjPRange thys)
 
 
 
+
 /* @func ajRangeIsWhole *******************************************************
 **
 ** Test whether the default range is used for a sequence
@@ -1986,6 +2018,7 @@ AjBool ajRangeIsWhole(const AjPRange thys, const AjPSeq s)
 
 
 
+
 /* @obsolete ajRangeDefault
 ** @rename ajRangeIsWhole
 */
