@@ -52,6 +52,8 @@ static void tableStrDelKey(void** key, void** value, void* cl);
 static void tableFreeSetExpand (void);
 
 
+
+
 /* @filesection ajtable ********************************************************
 **
 ** @nam1rule aj Function belongs to the AJAX library.
@@ -75,6 +77,7 @@ static void tableFreeSetExpand (void);
 
 
 
+
 /* @section Comparison functions **********************************************
 **
 ** @fdata [AjPTable]
@@ -97,6 +100,8 @@ static void tableFreeSetExpand (void);
 ******************************************************************************/
 
 
+
+
 /* @funcstatic tableCmpAtom ***************************************************
 **
 ** Default comparison function for key comparison
@@ -153,6 +158,9 @@ static ajuint tableHashAtom(const void *key, ajuint hashsize)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTableNewFunctionLen *************************************************
 **
 ** creates, initialises, and returns a new, empty table that expects
@@ -290,8 +298,8 @@ AjPTable ajTableNewLen(ajuint size)
 **
 ** Retrieves values from a hash table
 **
-** @nam3rule Fetch Retrieval fuction
-** @nam4rule FetchKey Key retrieval fuction
+** @nam3rule Fetch Retrieval function
+** @nam4rule FetchKey Key retrieval function
 ** @nam3rule Get return attribute
 ** @nam4rule GetLength Table size
 ** @nam3rule Toarray Return keys and values as arrays
@@ -311,6 +319,9 @@ AjPTable ajTableNewLen(ajuint size)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTableFetch *********************************************************
 **
 ** Returns the value associated with key in table, or null
@@ -483,6 +494,9 @@ ajuint ajTableToarrayKeys(const AjPTable table,
     return table->length;
 }
 
+
+
+
 /* @obsolete ajTableToarray
 ** @rename ajTableToarrayKeysValues
 */
@@ -495,6 +509,8 @@ __deprecated ajuint ajTableToarray(const AjPTable table,
 }
 
 
+
+
 /* @func ajTableToarrayKeysValues *********************************************
 **
 ** creates two N+1 element arrays that holds the N key-value pairs
@@ -542,6 +558,9 @@ ajuint ajTableToarrayKeysValues(const AjPTable table,
     return table->length;
 }
 
+
+
+
 /* @func ajTableToarrayValues *************************************************
 **
 ** creates two N+1 element arrays that holds the N values
@@ -582,6 +601,9 @@ ajuint ajTableToarrayValues(const AjPTable table,
     return table->length;
 }
 
+
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjPTable]
@@ -595,6 +617,8 @@ ajuint ajTableToarrayValues(const AjPTable table,
 ******************************************************************************/
 
 
+
+
 /* @func ajTableTrace *********************************************************
 **
 ** Writes debug messages to trace the contents of a table.
@@ -652,7 +676,7 @@ void ajTableTrace(const AjPTable table)
 ** @argrule Put key [void*] Key
 ** @argrule Put value [void*] Value
 ** @argrule Remove key [const void*] Key
-** @argrule RemoveKey truekey [void**] Removed key poiner - ready to be freed
+** @argrule RemoveKey truekey [void**] Removed key pointer - ready to be freed
 **
 ** @valrule * [void*] Previous value for key, or NULL
 **
@@ -660,6 +684,8 @@ void ajTableTrace(const AjPTable table)
 ******************************************************************************/
 
 
+
+
 /* @func ajTablePut ***********************************************************
 **
 ** change the value associated with key in table to value and returns
@@ -843,6 +869,8 @@ void * ajTableRemoveKey(AjPTable table, const void *key, void** truekey)
 ******************************************************************************/
 
 
+
+
 /* @func ajTableMap **********************************************************
 **
 ** calls function 'apply' for each key-value in table
@@ -962,6 +990,9 @@ void ajTableMapDel(AjPTable table,
 **
 ******************************************************************************/
 
+
+
+
 /* @funcstatic tableFreeSetExpand **********************************************
 **
 ** Expand the list of free structure bindings
@@ -991,8 +1022,9 @@ static void tableFreeSetExpand (void)
     return;
 }
 
-    
-    
+
+
+
 /* @func ajTableFree **********************************************************
 **
 ** Deallocates and clears a hash table. Does not clear keys or values.
@@ -1119,6 +1151,9 @@ void ajTableExit(void)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTablestrNew ********************************************************
 **
 ** Creates, initialises, and returns a new, empty table that can hold an
@@ -1209,7 +1244,7 @@ AjPTable ajTablestrNewLen(ajuint size)
 **
 ** Retrieves values from a hash table
 **
-** @nam3rule Fetch Retrieval fuction
+** @nam3rule Fetch Retrieval function
 **
 ** @argrule Fetch table [const AjPTable] Hash table
 ** @argrule Fetch key [const AjPStr] Key
@@ -1220,6 +1255,9 @@ AjPTable ajTablestrNewLen(ajuint size)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTablestrFetch ******************************************************
 **
 ** returns the value associated with key in table, or null
@@ -1272,6 +1310,9 @@ const AjPStr ajTablestrFetch(const AjPTable table, const AjPStr key)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTablestrFetchmod ***************************************************
 **
 ** returns the value associated with key in table, or null
@@ -1330,6 +1371,8 @@ AjPStr* ajTablestrFetchmod(AjPTable table, const AjPStr key)
 ******************************************************************************/
 
 
+
+
 /* @func ajTablestrCmp ********************************************************
 **
 ** Comparison function for a table with a string key
@@ -1502,6 +1545,8 @@ __deprecated ajuint ajStrTableHashCase(const void* key, ajuint hashsize)
 ******************************************************************************/
 
 
+
+
 /* @func ajTablestrPrint ******************************************************
 **
 ** Print function for a table with a string key.
@@ -1565,7 +1610,7 @@ void ajTablestrTrace(const AjPTable table)
     ajDebug("(string) table trace: ");
     ajDebug(" length: %d", table->length);
     ajDebug(" size: %d", table->size);
-    ajDebug(" timestamp: %u", table->timestamp);
+    ajDebug(" timestamp: %u\n", table->timestamp);
 
     for(i = 0; i < table->size; i++)
 	if(table->buckets[i])
@@ -1623,6 +1668,9 @@ __deprecated void ajStrTableTrace(const AjPTable table)
 **
 ******************************************************************************/
 
+
+
+
 /* @func ajTablestrFree *******************************************************
 **
 ** Free keys and value strings in a table and free the table.
@@ -1637,6 +1685,9 @@ __deprecated void ajStrTableTrace(const AjPTable table)
 
 void ajTablestrFree(AjPTable* Ptable)
 {
+    if(!Ptable)
+        return;
+
     if(!*Ptable)
 	return;
 
@@ -1776,6 +1827,9 @@ static void tableStrDelKey(void** key, void** value, void* cl)
 **
 ******************************************************************************/
 
+
+
+
 /* @section Constructors ******************************************************
 **
 ** Constructors for hash tables
@@ -1794,6 +1848,7 @@ static void tableStrDelKey(void** key, void** value, void* cl)
 
 
 
+
 /* @func ajTablecharNew ***************************************************
 **
 ** Creates a table with a character string key.
@@ -1931,6 +1986,8 @@ __deprecated AjPTable ajStrTableNew(ajuint hint)
 ******************************************************************************/
 
 
+
+
 /* @func ajTablecharCmp *******************************************************
 **
 ** Comparison function for a table with a character string key
@@ -2099,6 +2156,8 @@ __deprecated ajuint ajStrTableHashCaseC(const void* key, ajuint hashsize)
 ******************************************************************************/
 
 
+
+
 /* @func ajTablecharPrint *****************************************************
 **
 ** Print function for a table with a character string key.
