@@ -4,7 +4,7 @@
 ** @author Copyright (C) 1999 Ensembl Developers
 ** @author Copyright (C) 2006 Michael K. Schuster
 ** @modified 2009 by Alan Bleasby for incorporation into EMBOSS core
-** @version $Revision: 1.5 $
+** @version $Revision: 1.9 $
 ** @@
 **
 ** This library is free software; you can redistribute it and/or
@@ -36,9 +36,9 @@
 /* ======================== private functions ========================= */
 /* ==================================================================== */
 
-/* Default empty SQL SELECT LEFT_JOIN statement. */
+/* Default empty SQL SELECT LEFT JOIN statement. */
 
-static EnsOBaseadaptorLeftJoin baseAdaptorLeftJoin[] =
+static EnsOBaseadaptorLeftJoin baseadaptorLeftJoin[] =
 {
     {NULL, NULL}
 };
@@ -51,12 +51,12 @@ static EnsOBaseadaptorLeftJoin baseAdaptorLeftJoin[] =
 ** length of 16, this means a maximum of 2048 identifiers in each statement.
 */
 
-const ajuint baseAdaptorFetchAllByIdentifiersMax = 2048;
+const ajuint baseadaptorFetchAllByIdentifiersMax = 2048;
 
 
 
-static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
-                                               AjPStr identifiers,
+static AjBool baseadaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
+                                               const AjPStr values,
                                                AjPList objects);
 
 
@@ -95,12 +95,8 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 ** @fnote None
 **
 ** @nam3rule New Constructor
-** @nam4rule NewObj Constructor with existing object
-** @nam4rule NewRef Constructor by incrementing the reference counter
 **
 ** @argrule New dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
-** @argrule Obj object [EnsPBaseadaptor] Ensembl Base Adaptor
-** @argrule Ref object [EnsPBaseadaptor] Ensembl Base Adaptor
 **
 ** @valrule * [EnsPBaseadaptor] Ensembl Base Adaptor
 **
@@ -118,11 +114,12 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 ** @param [r] dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
 ** @param [r] Ptables [const char**] Array of char strings of table names
 ** @param [r] Pcolumns [const char**] Array of char strings of column names
-** @param [r] left_join [EnsOBaseadaptorLeftJoin*] Address of an array of
-**                                   Ensembl Base Adaptor Left Join Statements
-** @param [r] condition [const char *] Default WHERE condition in a
+** @param [r] leftjoin [EnsOBaseadaptorLeftJoin*] Address of an array of
+**                                                Ensembl Base Adaptor
+**                                                LEFT JOIN statements
+** @param [r] condition [const char*] Default WHERE condition in a
 **                                     SQL SELECT statement
-** @param [r] final [const char *] Final condition in a
+** @param [r] final [const char*] Final condition in a
 **                                 SQL SELECT statement
 ** @param [f] Fquery [AjBool function] Pointer to a function to handle the
 **                              Ensembl Object-specific SQL statement
@@ -135,7 +132,7 @@ EnsPBaseadaptor ensBaseadaptorNew(
     EnsPDatabaseadaptor dba,
     const char **Ptables,
     const char **Pcolumns,
-    EnsOBaseadaptorLeftJoin *left_join,
+    EnsOBaseadaptorLeftJoin *leftjoin,
     const char *condition,
     const char *final,
     AjBool Fquery(EnsPDatabaseadaptor dba,
@@ -163,11 +160,10 @@ EnsPBaseadaptor ensBaseadaptorNew(
 
     ba->Columns = Pcolumns;
 
-    if(left_join)
-        ba->LeftJoin = left_join;
-
+    if(leftjoin)
+        ba->LeftJoin = leftjoin;
     else
-        ba->LeftJoin = baseAdaptorLeftJoin;
+        ba->LeftJoin = baseadaptorLeftJoin;
 
     ba->DefaultCondition = condition;
 
@@ -213,13 +209,17 @@ EnsPBaseadaptor ensBaseadaptorNew(
 
 void ensBaseadaptorDel(EnsPBaseadaptor *Pba)
 {
+    EnsPBaseadaptor pthis = NULL;
+
     if(!Pba)
         return;
 
     if(!*Pba)
         return;
 
-    AJFREE(*Pba);
+    pthis = *Pba;
+
+    AJFREE(pthis);
 
     *Pba = NULL;
 
@@ -287,7 +287,7 @@ EnsPDatabaseadaptor ensBaseadaptorGetDatabaseadaptor(const EnsPBaseadaptor ba)
 ** @@
 ******************************************************************************/
 
-const char **ensBaseadaptorGetTables(const EnsPBaseadaptor ba)
+const char** ensBaseadaptorGetTables(const EnsPBaseadaptor ba)
 {
     if(!ba)
         return NULL;
@@ -310,7 +310,7 @@ const char **ensBaseadaptorGetTables(const EnsPBaseadaptor ba)
 ** @@
 ******************************************************************************/
 
-const char **ensBaseadaptorGetColumns(const EnsPBaseadaptor ba)
+const char** ensBaseadaptorGetColumns(const EnsPBaseadaptor ba)
 {
     if(!ba)
         return NULL;
@@ -408,7 +408,7 @@ AjBool ensBaseadaptorSetColumns(EnsPBaseadaptor ba, const char ** Pcolumns)
 **
 ** @cc Bio::EnsEMBL::DBSQL::BaseAdaptor::_default_where_clause
 ** @param [r] ba [EnsPBaseadaptor] Ensembl Base Adaptor
-** @param [r] condition [const char *] Default SQL condition
+** @param [r] condition [const char*] Default SQL condition
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
 ** @@
@@ -434,7 +434,7 @@ AjBool ensBaseadaptorSetDefaultCondition(EnsPBaseadaptor ba,
 **
 ** @cc Bio::EnsEMBL::DBSQL::BaseAdaptor::_final_clause
 ** @param [r] ba [EnsPBaseadaptor] Ensembl Base Adaptor
-** @param [r] final [const char *] Final SQL condition
+** @param [r] final [const char*] Final SQL condition
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
 ** @@
@@ -460,12 +460,12 @@ AjBool ensBaseadaptorSetFinalCondition(EnsPBaseadaptor ba, const char *final)
 **
 ** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor
 **
-** @return [const char *] Address of the primary table name character strings
+** @return [const char*] Address of the primary table name character strings
 **                        or NULL
 ** @@
 ******************************************************************************/
 
-const char *ensBaseadaptorGetPrimaryTable(const EnsPBaseadaptor ba)
+const char* ensBaseadaptorGetPrimaryTable(const EnsPBaseadaptor ba)
 {
     if(!ba)
         return NULL;
@@ -672,7 +672,7 @@ AjBool ensBaseadaptorGenericFetch(const EnsPBaseadaptor ba,
     ** features in multi-species databases to the seq_region and coord_system
     ** tables.
     ** The problem is to find out that the query is for a Feature sub class and
-    ** not just for an Object fetched via the Base Adaptor like Anaylsis, which
+    ** not just for an Object fetched via the Base Adaptor like Analysis, which
     ** is not a Feature.
     **
     ** Maybe this functionality should just move into the Feature Adaptor?
@@ -811,11 +811,11 @@ AjBool ensBaseadaptorGenericFetch(const EnsPBaseadaptor ba,
 ** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor
 ** @param [r] identifier [ajuint] SQL database-internal identifier
 **
-** @return [void *] Ensembl Object or NULL
+** @return [void*] Ensembl Object or NULL
 ** @@
 ******************************************************************************/
 
-void *ensBaseadaptorFetchByIdentifier(const EnsPBaseadaptor ba,
+void* ensBaseadaptorFetchByIdentifier(const EnsPBaseadaptor ba,
                                       ajuint identifier)
 {
     void *Pobject = NULL;
@@ -862,24 +862,24 @@ void *ensBaseadaptorFetchByIdentifier(const EnsPBaseadaptor ba,
 
 
 
-/* @funcstatic baseAdaptorFetchAllByIdentifiers *******************************
+/* @funcstatic baseadaptorFetchAllByIdentifiers *******************************
 **
 ** Helper function for the generic function to fetch Ensembl Objects by an
 ** AJAX List of SQL database-internal identifiers via an Ensembl Base Adaptor.
 **
 ** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor
-** @param [r] identifiers [AjPStr] Comma-separated list of SQL database-
-**                                 internal identifiers used in an IN
-**                                 comparison function in a SQL SELECT
-**                                 statement
+** @param [r] values [const AjPStr] Comma-separated values of SQL database-
+**                                  internal identifiers used in an IN
+**                                  comparison function in a SQL SELECT
+**                                  statement
 ** @param [u] objects [AjPList] AJAX List of Ensembl Objects
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
 ** @@
 ******************************************************************************/
 
-static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
-                                               AjPStr identifiers,
+static AjBool baseadaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
+                                               const AjPStr values,
                                                AjPList objects)
 {
     AjPStr constraint = NULL;
@@ -887,7 +887,7 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
     if(!ba)
         return ajFalse;
 
-    if(!identifiers)
+    if(!values)
         return ajFalse;
 
     if(!objects)
@@ -907,7 +907,7 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
     constraint = ajFmtStr("%s.%s_id IN (%S)",
                           ba->Tables[0],
                           ba->Tables[0],
-                          identifiers);
+                          values);
 
     ensBaseadaptorGenericFetch(ba,
                                constraint,
@@ -930,10 +930,10 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 **
 ** @cc Bio::EnsEMBL::DBSQL::BaseAdaptor::fetch_all_by_dbID_list
 ** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor.
-** @param [r] idlist [AjPList] AJAX List of AJAX unsigned integers of
-**                             SQL database-internal identifiers
-**                             used in an IN comparison function in a
-**                             SQL SELECT statement
+** @param [r] identifiers [const AjPList] AJAX List of AJAX unsigned integers
+**                                        of SQL database-internal identifiers
+**                                        used in an IN comparison function in
+**                                        a SQL SELECT statement
 ** @param [u] objects [AjPList] AJAX List of Ensembl Objects
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
@@ -941,7 +941,7 @@ static AjBool baseAdaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 ******************************************************************************/
 
 AjBool ensBaseadaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
-                                           AjPList idlist,
+                                           const AjPList identifiers,
                                            AjPList objects)
 {
     register ajuint i = 0;
@@ -950,40 +950,40 @@ AjBool ensBaseadaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 
     AjIList iter = NULL;
 
-    AjPStr identifiers = NULL;
+    AjPStr values = NULL;
 
     if(!ba)
         return ajFalse;
 
-    if(!idlist)
+    if(!identifiers)
         return ajFalse;
 
     if(!objects)
         return ajFalse;
 
-    iter = ajListIterNew(idlist);
+    iter = ajListIterNewread(identifiers);
 
-    identifiers = ajStrNew();
+    values = ajStrNew();
 
     while(!ajListIterDone(iter))
     {
         Pidentifier = (ajuint *) ajListIterGet(iter);
 
-        ajFmtPrintAppS(&identifiers, "%u, ", *Pidentifier);
+        ajFmtPrintAppS(&values, "%u, ", *Pidentifier);
 
         i++;
 
         /* Run the statement if we exceed the maximum chunk size. */
 
-        if(i >= baseAdaptorFetchAllByIdentifiersMax)
+        if(i >= baseadaptorFetchAllByIdentifiersMax)
         {
             /* Remove the last comma and space. */
 
-            ajStrCutEnd(&identifiers, 2);
+            ajStrCutEnd(&values, 2);
 
-            baseAdaptorFetchAllByIdentifiers(ba, identifiers, objects);
+            baseadaptorFetchAllByIdentifiers(ba, values, objects);
 
-            ajStrAssignClear(&identifiers);
+            ajStrAssignClear(&values);
 
             i = 0;
         }
@@ -995,11 +995,11 @@ AjBool ensBaseadaptorFetchAllByIdentifiers(const EnsPBaseadaptor ba,
 
     /* Remove the last comma and space. */
 
-    ajStrCutEnd(&identifiers, 2);
+    ajStrCutEnd(&values, 2);
 
-    baseAdaptorFetchAllByIdentifiers(ba, identifiers, objects);
+    baseadaptorFetchAllByIdentifiers(ba, values, objects);
 
-    ajStrDel(&identifiers);
+    ajStrDel(&values);
 
     return ajTrue;
 }
@@ -1049,36 +1049,39 @@ AjBool ensBaseadaptorFetchAll(const EnsPBaseadaptor ba, AjPList objects)
 **
 ** @cc Bio::EnsEMBL::DBSQL::BaseAdaptor::_list_dbIDs
 ** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor
-** @param [r] table [AjPStr] SQL table name
-** @param [r] prikey [AjPStr] Primary key of the SQL table
-** @param [u] idlist [AjPList] AJAX List of AJAX unsigned integer
-**                             SQL database-internal identifiers
+** @param [r] table [const AjPStr] SQL table name
+** @param [rN] primary [const AjPStr] Primary key of the SQL table
+** @param [u] identifiers [AjPList] AJAX List of AJAX unsigned integer
+**                                  SQL database-internal identifiers
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
 ** @@
 ******************************************************************************/
 
 AjBool ensBaseadaptorFetchAllIdentifiers(const EnsPBaseadaptor ba,
-                                         AjPStr table,
-                                         AjPStr prikey,
-                                         AjPList idlist)
+                                         const AjPStr table,
+                                         const AjPStr primary,
+                                         AjPList identifiers)
 {
     ajuint *Pid = NULL;
 
     AjPSqlstatement sqls = NULL;
-    AjISqlrow sqli = NULL;
-    AjPSqlrow sqlr = NULL;
+    AjISqlrow sqli       = NULL;
+    AjPSqlrow sqlr       = NULL;
 
     AjPStr statement = NULL;
 
     if(!ba)
         return ajFalse;
 
-    if(!idlist)
+    if(!table)
         return ajFalse;
 
-    if(prikey && ajStrGetLen(prikey))
-        statement = ajFmtStr("SELECT %S.%S FROM %S", table, prikey, table);
+    if(!identifiers)
+        return ajFalse;
+
+    if(primary && ajStrGetLen(primary))
+        statement = ajFmtStr("SELECT %S.%S FROM %S", table, primary, table);
     else
         statement = ajFmtStr("SELECT %S.%S_id FROM %S", table, table, table);
 
@@ -1094,12 +1097,84 @@ AjBool ensBaseadaptorFetchAllIdentifiers(const EnsPBaseadaptor ba,
 
         ajSqlcolumnToUint(sqlr, Pid);
 
-        ajListPushAppend(idlist, (void *) Pid);
+        ajListPushAppend(identifiers, (void *) Pid);
     }
 
     ajSqlrowiterDel(&sqli);
 
-    ajSqlstatementDel(&sqls);
+    ensDatabaseadaptorSqlstatementDel(ba->Adaptor, &sqls);
+
+    ajStrDel(&statement);
+
+    return ajTrue;
+}
+
+
+
+
+/* @func ensBaseadaptorFetchAllStrings ****************************************
+**
+** Generic function to fetch SQL database-internal strings of
+** Ensembl Objects via an Ensembl Base Adaptor.
+**
+** The caller is responsible for deleting the AJAX Strings before
+** deleting the AJAX List.
+**
+** @cc Bio::EnsEMBL::DBSQL::BaseAdaptor::_list_dbIDs
+** @param [r] ba [const EnsPBaseadaptor] Ensembl Base Adaptor
+** @param [r] table [const AjPStr] SQL table name
+** @param [rN] primary [const AjPStr] Primary key of the SQL table
+** @param [u] strings [AjPList] AJAX List of AJAX String
+**                              SQL database-internal strings
+**
+** @return [AjBool] ajTrue upon success, ajFalse otherwise
+** @@
+******************************************************************************/
+
+AjBool ensBaseadaptorFetchAllStrings(const EnsPBaseadaptor ba,
+                                     const AjPStr table,
+                                     const AjPStr primary,
+                                     AjPList strings)
+{
+    AjPSqlstatement sqls = NULL;
+    AjISqlrow sqli       = NULL;
+    AjPSqlrow sqlr       = NULL;
+
+    AjPStr statement = NULL;
+    AjPStr string    = NULL;
+
+    if(!ba)
+        return ajFalse;
+
+    if(!table)
+        return ajFalse;
+
+    if(!strings)
+        return ajFalse;
+
+    if(primary && ajStrGetLen(primary))
+        statement = ajFmtStr("SELECT %S.%S FROM %S", table, primary, table);
+    else
+        statement = ajFmtStr("SELECT %S.%S_id FROM %S", table, table, table);
+
+    sqls = ensDatabaseadaptorSqlstatementNew(ba->Adaptor, statement);
+
+    sqli = ajSqlrowiterNew(sqls);
+
+    while(!ajSqlrowiterDone(sqli))
+    {
+        string = ajStrNew();
+
+        sqlr = ajSqlrowiterGet(sqli);
+
+        ajSqlcolumnToStr(sqlr, &string);
+
+        ajListPushAppend(strings, (void *) string);
+    }
+
+    ajSqlrowiterDel(&sqli);
+
+    ensDatabaseadaptorSqlstatementDel(ba->Adaptor, &sqls);
 
     ajStrDel(&statement);
 
