@@ -4,7 +4,7 @@
 ** @author Copyright (C) 1999 Ensembl Developers
 ** @author Copyright (C) 2006 Michael K. Schuster
 ** @modified 2009 by Alan Bleasby for incorporation into EMBOSS core
-** @version $Revision: 1.3 $
+** @version $Revision: 1.12 $
 ** @@
 **
 ** This library is free software; you can redistribute it and/or
@@ -28,6 +28,7 @@
 /* ==================================================================== */
 
 #include "ensdatabaseadaptor.h"
+#include "ensmetainformation.h"
 
 
 
@@ -36,7 +37,7 @@
 /* ========================== private data ============================ */
 /* ==================================================================== */
 
-static const char *databaseAdaptorGroup[] =
+static const char *databaseadaptorGroup[] =
 {
     NULL,
     "core",
@@ -46,7 +47,7 @@ static const char *databaseAdaptorGroup[] =
     "variation",
     "funcgen",
     "compara",
-    "go",
+    "ontology",
     "qc",
     "pipeline",
     "hive",
@@ -54,6 +55,7 @@ static const char *databaseAdaptorGroup[] =
     "coreexpressiongnf",
     "ancestral",
     "website",
+    "production",
     NULL
 };
 
@@ -80,7 +82,7 @@ static const char *databaseAdaptorGroup[] =
 **
 ** Functions for manipulating Ensembl Database Adaptor objects
 **
-** @cc Bio::EnsEMBL::DBSQL::DBAdaptor CVS Revision: 1.192
+** @cc Bio::EnsEMBL::DBSQL::DBAdaptor CVS Revision: 1.208
 **
 ** @nam2rule Databaseadaptor
 **
@@ -100,11 +102,13 @@ static const char *databaseAdaptorGroup[] =
 ** @fnote None
 **
 ** @nam3rule New Constructor
-** @nam4rule NewObj Constructor with existing object
-** @nam4rule NewRef Constructor by incrementing the reference counter
 **
-** @argrule Obj object [EnsPDatabaseadaptor] Ensembl Database Adaptor
-** @argrule Ref object [EnsPDatabaseadaptor] Ensembl Database Adaptor
+** @argrule New dbc [EnsPDatabaseconnection] Ensembl Database Connection
+** @argrule New database [AjPStr] Database name
+** @argrule New species [AjPStr] Species
+** @argrule New group [EnsEDatabaseadaptorGroup] Group
+** @argrule New multi [AjBool] Multiple species
+** @argrule New identifier [ajuint] Species identifier
 **
 ** @valrule * [EnsPDatabaseadaptor] Ensembl Database Adaptor
 **
@@ -118,10 +122,16 @@ static const char *databaseAdaptorGroup[] =
 **
 ** Default Ensembl Database Adaptor constructor.
 **
-** This function should not be called directly, rather the
-** ensRegistryAddDatabaseadaptor and ensRegistryGetDatabaseadaptor functions
-** should be used to instantiate an Ensembl Database Adaptor in the
-** Ensembl Registry and subsequently return it for use.
+** Ensembl Database Adaptors are singleton objects in the sense that a single
+** instance of an Ensembl Database Adaptor connected to a particular database
+** is sufficient to instantiate any number of Ensembl Object Adaptors from the
+** database. Each Ensembl Object Adaptor will have a weak reference to the
+** Ensembl Database Adaptor that instantiated it. Therefore, Ensembl Database
+** Adaptors should not be instantiated directly, but rather obtained from the
+** Ensembl Registry, which will in turn call this function if neccessary.
+**
+** @see ensRegistryNewDatabaseadaptor
+** @see ensRegistryGetDatabaseadaptor
 **
 ** @cc Bio::EnsEMBL::DBSQL::DBAdaptor::new
 ** @param [r] dbc [EnsPDatabaseconnection] Ensembl Database Connection
@@ -129,7 +139,7 @@ static const char *databaseAdaptorGroup[] =
 **                              database name in the Database Connection will
 **                              be used.
 ** @param [u] species [AjPStr] Species
-** @param [r] group [AjEnum] Group
+** @param [r] group [EnsEDatabaseadaptorGroup] Group
 ** @param [r] multi [AjBool] Multiple species
 ** @param [r] identifier [ajuint] Species identifier
 **
@@ -146,52 +156,53 @@ EnsPDatabaseadaptor ensDatabaseadaptorNew(
     EnsPDatabaseconnection dbc,
     AjPStr database,
     AjPStr species,
-    AjEnum group,
+    EnsEDatabaseadaptorGroup group,
     AjBool multi,
     ajuint identifier)
 {
     EnsPDatabaseadaptor dba = NULL;
-    
-    /*
-     ajDebug("ensDatabaseadaptorNew\n"
-	     "  dbc %p\n"
-	     "  database '%S'\n"
-	     "  species '%S'\n"
-	     "  group %d\n"
-	     "  multi %B\n"
-	     "  identifier %u\n",
-	     dbc,
-	     database,
-	     species,
-	     group,
-	     multi,
-	     identifier);
-     
-     ensDatabaseconnectionTrace(dbc, 1);
-     */
-    
+
+    if(ajDebugTest("ensDatabaseadaptorNew"))
+    {
+        ajDebug("ensDatabaseadaptorNew\n"
+                "  dbc %p\n"
+                "  database '%S'\n"
+                "  species '%S'\n"
+                "  group %d\n"
+                "  multi %B\n"
+                "  identifier %u\n",
+                dbc,
+                database,
+                species,
+                group,
+                multi,
+                identifier);
+
+        ensDatabaseconnectionTrace(dbc, 1);
+    }
+
     if(!dbc)
         return NULL;
-    
+
     if(!species)
         return NULL;
-    
+
     if(!group)
         return NULL;
-    
+
     AJNEW0(dba);
-    
+
     dba->Databaseconnection = ensDatabaseconnectionNewC(dbc, database);
-    
+
     if(species)
-	dba->Species = ajStrNewRef(species);
-    
+        dba->Species = ajStrNewRef(species);
+
     dba->Group = group;
-    
+
     dba->MultiSpecies = multi;
-    
+
     dba->Identifier = identifier;
-    
+
     return dba;
 }
 
@@ -223,11 +234,14 @@ EnsPDatabaseadaptor ensDatabaseadaptorNew(
 **
 ** Default Ensembl Database Adaptor destructor.
 **
-** This function should only be called for Ensembl Database Adaptors that have
-** been instantiated outside the ensRegistryAddDatabaseadaptor function.
-** For all other Database Adaptors ensRegistryRemoveDatabaseadaptor can be
-** used to destroy a particular Ensembl Database Adaptor. All remaining
-** Database Adaptors will be automatically cleared from the Registry upon exit.
+** Ensembl Database Adaptors are singleton objects that are registered in the
+** Ensembl Registry and weakly referenced by Ensembl Object Adaptors that have
+** been instantiated by it. Therefore, Ensembl Database Adaptors should never
+** be destroyed directly. Upon exit, the Ensembl Registry will call this
+** function if required.
+**
+** @see ensExit
+** @see ensRegistryExit
 **
 ** @param [d] Pdba [EnsPDatabaseadaptor*] Ensembl Database Adaptor address
 **
@@ -242,31 +256,34 @@ EnsPDatabaseadaptor ensDatabaseadaptorNew(
 void ensDatabaseadaptorDel(EnsPDatabaseadaptor* Pdba)
 {
     EnsPDatabaseadaptor pthis = NULL;
-    
+
     if(!Pdba)
         return;
-    
+
     if(!*Pdba)
         return;
 
+    if(ajDebugTest("ensDatabaseadaptorDel"))
+    {
+        ajDebug("ensDatabaseadaptorDel\n"
+                "  *Pdba %p\n",
+                *Pdba);
+
+        ensDatabaseadaptorTrace(*Pdba, 1);
+    }
+
     pthis = *Pdba;
-    
-    /*
-     ajDebug("ensDatabaseadaptorDel\n"
-	     "  *Pdba %p\n",
-	     *Pdba);
-     
-     ensDatabaseadaptorDebug(*Pdba, 1);
-     */
-    
+
     ensDatabaseconnectionDel(&pthis->Databaseconnection);
-    
+
     ajStrDel(&pthis->Species);
-    
+
+    ajListstrFreeData(&pthis->SpeciesNames);
+
     AJFREE(pthis);
 
     *Pdba = NULL;
-    
+
     return;
 }
 
@@ -292,7 +309,7 @@ void ensDatabaseadaptorDel(EnsPDatabaseadaptor* Pdba)
 ** @valrule Databaseconnection [EnsPDatabaseconnection] Ensembl Database
 **                                                      Connection
 ** @valrule Species [AjPStr] Species
-** @valrule Group [AjEnum] Group
+** @valrule Group [EnsEDatabaseadaptorGroup] Group
 ** @valrule MultiSpecies [AjBool] Multiple species
 ** @valrule Identifier [ajuint] Species identifier
 **
@@ -318,7 +335,7 @@ EnsPDatabaseconnection ensDatabaseadaptorGetDatabaseconnection(
 {
     if(!dba)
         return NULL;
-    
+
     return dba->Databaseconnection;
 }
 
@@ -340,7 +357,7 @@ AjPStr ensDatabaseadaptorGetSpecies(const EnsPDatabaseadaptor dba)
 {
     if(!dba)
         return NULL;
-    
+
     return dba->Species;
 }
 
@@ -354,15 +371,16 @@ AjPStr ensDatabaseadaptorGetSpecies(const EnsPDatabaseadaptor dba)
 ** @cc Bio::EnsEMBL::DBSQL::DBAdaptor::group
 ** @param [r] dba [const EnsPDatabaseadaptor] Ensembl Database Adaptor
 **
-** @return [AjPStr] Group or ensEDatabaseadaptorGroupNULL
+** @return [EnsEDatabaseadaptorGroup] Group or ensEDatabaseadaptorGroupNULL
 ** @@
 ******************************************************************************/
 
-AjEnum ensDatabaseadaptorGetGroup(const EnsPDatabaseadaptor dba)
+EnsEDatabaseadaptorGroup ensDatabaseadaptorGetGroup(
+    const EnsPDatabaseadaptor dba)
 {
     if(!dba)
         return ensEDatabaseadaptorGroupNULL;
-    
+
     return dba->Group;
 }
 
@@ -384,7 +402,7 @@ AjBool ensDatabaseadaptorGetMultiSpecies(const EnsPDatabaseadaptor dba)
 {
     if(!dba)
         return ajFalse;
-    
+
     return dba->MultiSpecies;
 }
 
@@ -406,10 +424,10 @@ ajuint ensDatabaseadaptorGetIdentifier(const EnsPDatabaseadaptor dba)
 {
     if(!dba)
         return 0;
-    
+
     if(!dba->Identifier)
-	return 1;
-    
+        return 1;
+
     return dba->Identifier;
 }
 
@@ -457,11 +475,11 @@ AjBool ensDatabaseadaptorSetDatabaseconnection(EnsPDatabaseadaptor dba,
 {
     if(!dba)
         return ajFalse;
-    
-    ensDatabaseconnectionDel(&(dba->Databaseconnection));
-    
+
+    ensDatabaseconnectionDel(&dba->Databaseconnection);
+
     dba->Databaseconnection = ensDatabaseconnectionNewRef(dbc);
-    
+
     return ajTrue;
 }
 
@@ -484,12 +502,12 @@ AjBool ensDatabaseadaptorSetSpecies(EnsPDatabaseadaptor dba, AjPStr species)
 {
     if(!dba)
         return ajFalse;
-    
+
     ajStrDel(&dba->Species);
-    
+
     if(species)
-	dba->Species = ajStrNewRef(species);
-    
+        dba->Species = ajStrNewRef(species);
+
     return ajTrue;
 }
 
@@ -502,19 +520,20 @@ AjBool ensDatabaseadaptorSetSpecies(EnsPDatabaseadaptor dba, AjPStr species)
 **
 ** @cc Bio::EnsEMBL::DBSQL::DBAdaptor::group
 ** @param [u] dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
-** @param [r] group [AjEnum] Group
+** @param [r] group [EnsEDatabaseadaptorGroup] Group
 **
 ** @return [AjBool] ajTrue upon success, ajFalse otherwise
 ** @@
 ******************************************************************************/
 
-AjBool ensDatabaseadaptorSetGroup(EnsPDatabaseadaptor dba, AjEnum group)
+AjBool ensDatabaseadaptorSetGroup(EnsPDatabaseadaptor dba,
+                                  EnsEDatabaseadaptorGroup group)
 {
     if(!dba)
         return ajFalse;
-    
+
     dba->Group = group;
-    
+
     return ajTrue;
 }
 
@@ -533,13 +552,14 @@ AjBool ensDatabaseadaptorSetGroup(EnsPDatabaseadaptor dba, AjEnum group)
 ** @@
 ******************************************************************************/
 
-AjBool ensDatabaseadaptorSetMultiSpecies(EnsPDatabaseadaptor dba, AjBool multi)
+AjBool ensDatabaseadaptorSetMultiSpecies(EnsPDatabaseadaptor dba,
+                                         AjBool multi)
 {
     if(!dba)
         return ajFalse;
-    
+
     dba->MultiSpecies = multi;
-    
+
     return ajTrue;
 }
 
@@ -563,9 +583,9 @@ AjBool ensDatabaseadaptorSetIdentifier(EnsPDatabaseadaptor dba,
 {
     if(!dba)
         return ajFalse;
-    
+
     dba->Identifier = identifier;
-    
+
     return ajTrue;
 }
 
@@ -578,25 +598,25 @@ AjBool ensDatabaseadaptorSetIdentifier(EnsPDatabaseadaptor dba,
 **
 ** @param [r] group [const AjPStr] Group string
 **
-** @return [AjEnum] Ensembl Database Adaptor group element or
-**                  ensEDatabaseadaptorGroupNULL
+** @return [EnsEDatabaseadaptorGroup] Ensembl Database Adaptor group element or
+**                                    ensEDatabaseadaptorGroupNULL
 ** @@
 ******************************************************************************/
 
-AjEnum ensDatabaseadaptorGroupFromStr(const AjPStr group)
+EnsEDatabaseadaptorGroup ensDatabaseadaptorGroupFromStr(const AjPStr group)
 {
-    register ajuint i = 0;
-    
-    AjEnum egroup = ensEDatabaseadaptorGroupNULL;
-    
-    for(i = 1; databaseAdaptorGroup[i]; i++)
-	if (ajStrMatchCaseC(group, databaseAdaptorGroup[i]))
-	    egroup = i;
-    
+    register EnsEDatabaseadaptorGroup i = ensEDatabaseadaptorGroupNULL;
+
+    EnsEDatabaseadaptorGroup egroup = ensEDatabaseadaptorGroupNULL;
+
+    for(i = ensEDatabaseadaptorGroupCore; databaseadaptorGroup[i]; i++)
+        if(ajStrMatchCaseC(group, databaseadaptorGroup[i]))
+            egroup = i;
+
     if(!egroup)
-	ajDebug("ensDatabaseadaptorGroupFromStr encountered "
-		"unexpected string '%S'.\n", group);
-    
+        ajDebug("ensDatabaseadaptorGroupFromStr encountered "
+                "unexpected string '%S'.\n", group);
+
     return egroup;
 }
 
@@ -608,26 +628,28 @@ AjEnum ensDatabaseadaptorGroupFromStr(const AjPStr group)
 ** Convert an Ensembl Database Adaptor group element into a
 ** C-type (char*) string.
 **
-** @param [r] group [const AjEnum] Database Adaptor group enumerator
+** @param [r] group [EnsEDatabaseadaptorGroup] Database Adaptor group
 **
 ** @return [const char*] Database Adaptor group C-type (char*) string
 ** @@
 ******************************************************************************/
 
-const char* ensDatabaseadaptorGroupToChar(const AjEnum group)
+const char* ensDatabaseadaptorGroupToChar(EnsEDatabaseadaptorGroup group)
 {
-    register ajint i = 0;
-    
+    register EnsEDatabaseadaptorGroup i = ensEDatabaseadaptorGroupNULL;
+
     if(!group)
-	return NULL;
-    
-    for(i = 1; databaseAdaptorGroup[i] && (i < group); i++);
-    
-    if(!databaseAdaptorGroup[i])
-	ajDebug("ensDatabaseadaptorGroupToChar encountered an "
-		"out of boundary error on group %d.\n", group);
-    
-    return databaseAdaptorGroup[i];
+        return NULL;
+
+    for(i = ensEDatabaseadaptorGroupCore;
+        databaseadaptorGroup[i] && (i < group);
+        i++);
+
+    if(!databaseadaptorGroup[i])
+        ajDebug("ensDatabaseadaptorGroupToChar encountered an "
+                "out of boundary error on group %d.\n", group);
+
+    return databaseadaptorGroup[i];
 }
 
 
@@ -652,29 +674,29 @@ AjBool ensDatabaseadaptorMatch(const EnsPDatabaseadaptor dba1,
 {
     if(!dba1)
         return ajFalse;
-    
+
     if(!dba2)
         return ajFalse;
-    
+
     if(dba1 == dba2)
-	return ajTrue;
-    
+        return ajTrue;
+
     if(!ensDatabaseconnectionMatch(dba1->Databaseconnection,
                                    dba2->Databaseconnection))
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba1->Group != dba2->Group)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba1->MultiSpecies != dba2->MultiSpecies)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba1->Identifier != dba2->Identifier)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!ajStrMatchCaseS(dba1->Species, dba2->Species))
-	return ajFalse;
-    
+        return ajFalse;
+
     return ajTrue;
 }
 
@@ -688,7 +710,7 @@ AjBool ensDatabaseadaptorMatch(const EnsPDatabaseadaptor dba1,
 ** @param [r] dba [const EnsPDatabaseadaptor] Ensembl Database Adaptor
 ** @param [r] dbc [const EnsPDatabaseconnection] Ensembl Database Connection
 ** @param [r] species [const AjPStr] Species
-** @param [r] group [AjEnum] Group
+** @param [r] group [EnsEDatabaseadaptorGroup] Group
 ** @param [r] multi [AjBool] Multiple species
 ** @param [r] identifier [ajuint] Species identifier
 **
@@ -699,37 +721,37 @@ AjBool ensDatabaseadaptorMatch(const EnsPDatabaseadaptor dba1,
 AjBool ensDatabaseadaptorMatchComponents(const EnsPDatabaseadaptor dba,
                                          const EnsPDatabaseconnection dbc,
                                          const AjPStr species,
-                                         AjEnum group,
+                                         EnsEDatabaseadaptorGroup group,
                                          AjBool multi,
                                          ajuint identifier)
 {
     if(!dba)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!dbc)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!species)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!group)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba->Group != group)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba->MultiSpecies != multi)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(dba->Identifier != identifier)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!ensDatabaseconnectionMatch(dba->Databaseconnection, dbc))
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!ajStrMatchCaseS(dba->Species, species))
-	return ajFalse;
-    
+        return ajFalse;
+
     return ajTrue;
 }
 
@@ -751,13 +773,70 @@ AjPSqlstatement ensDatabaseadaptorSqlstatementNew(EnsPDatabaseadaptor dba,
                                                   const AjPStr statement)
 {
     if(!dba)
-	return NULL;
-    
+        return NULL;
+
     if(!statement)
-	return NULL;
-    
+        return NULL;
+
     return ensDatabaseconnectionSqlstatementNew(dba->Databaseconnection,
-						statement);
+                                                statement);
+}
+
+
+
+
+/* @func ensDatabaseadaptorSqlstatementDel ************************************
+**
+** Delete an AJAX SQL Statement associated with an
+** Ensembl Database Adaptor.
+**
+** @param [u] dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
+** @param [d] Psqls [AjPSqlstatement*] AJAX SQL Statement address
+**
+** @return [AjBool] ajTrue upon success, ajFalse otherwise
+** @@
+******************************************************************************/
+
+AjBool ensDatabaseadaptorSqlstatementDel(EnsPDatabaseadaptor dba,
+                                         AjPSqlstatement *Psqls)
+{
+    if(!dba)
+        return ajFalse;
+
+    if(!Psqls)
+        return ajFalse;
+
+    if(ajDebugTest("ensDatabaseadaptorSqlstatementDel"))
+        ajDebug("ensDatabaseadaptorSqlstatementDel\n"
+                "  dba %p\n"
+                "  PSqls %p\n",
+                dba,
+                Psqls);
+
+    return ensDatabaseconnectionSqlstatementDel(dba->Databaseconnection,
+                                                Psqls);
+}
+
+
+
+
+/* @func ensDatabaseadaptorDisconnect *****************************************
+**
+** Disconnect the Ensembl Database Connection this Ensembl Database Adaptor
+** is based on.
+**
+** @param [u] dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
+**
+** @return [AjBool] ajTrue upon success, ajFalse otherwise
+** @@
+******************************************************************************/
+
+AjBool ensDatabaseadaptorDisconnect(EnsPDatabaseadaptor dba)
+{
+    if(!dba)
+        return ajFalse;
+
+    return ensDatabaseconnectionDisconnect(dba->Databaseconnection);
 }
 
 
@@ -777,27 +856,28 @@ AjPSqlstatement ensDatabaseadaptorSqlstatementNew(EnsPDatabaseadaptor dba,
 ******************************************************************************/
 
 AjBool ensDatabaseadaptorEscapeC(EnsPDatabaseadaptor dba,
-                                  char **Ptxt,
-                                  const AjPStr str)
+                                 char **Ptxt,
+                                 const AjPStr str)
 {
     if(!dba)
         return ajFalse;
-    
+
     if(!str)
-	return ajFalse;
-    
-    /*
-     ajDebug("ensDatabaseadaptorEscapeC\n"
-	     "  dba %p\n"
-	     "  Ptxt %p\n"
-	     "  str '%S'\n",
-	     dba,
-	     Ptxt,
-	     str);
-     
-     ensDatabaseadaptorTrace(dba, 1);
-     */
-    
+        return ajFalse;
+
+    if(ajDebugTest("ensDatabaseadaptorEscapeC"))
+    {
+        ajDebug("ensDatabaseadaptorEscapeC\n"
+                "  dba %p\n"
+                "  Ptxt %p\n"
+                "  str '%S'\n",
+                dba,
+                Ptxt,
+                str);
+
+        ensDatabaseadaptorTrace(dba, 1);
+    }
+
     return ensDatabaseconnectionEscapeC(dba->Databaseconnection, Ptxt, str);
 }
 
@@ -818,27 +898,28 @@ AjBool ensDatabaseadaptorEscapeC(EnsPDatabaseadaptor dba,
 ******************************************************************************/
 
 AjBool ensDatabaseadaptorEscapeS(EnsPDatabaseadaptor dba,
-                                  AjPStr *Pstr,
-                                  const AjPStr str)
+                                 AjPStr *Pstr,
+                                 const AjPStr str)
 {
     if(!dba)
         return ajFalse;
-    
+
     if(!str)
-	return ajFalse;
-    
-    /*
-     ajDebug("ensDatabaseadaptorEscapeS\n"
-	     "  dba %p\n"
-	     "  Pstr %p\n"
-	     "  str '%S'\n",
-	     dba,
-	     Pstr,
-	     str);
-     
-     ensDatabaseadaptorTrace(dba, 1);
-     */
-    
+        return ajFalse;
+
+    if(ajDebugTest("ensDatabaseadaptorEscapeS"))
+    {
+        ajDebug("ensDatabaseadaptorEscapeS\n"
+                "  dba %p\n"
+                "  Pstr %p\n"
+                "  str '%S'\n",
+                dba,
+                Pstr,
+                str);
+
+        ensDatabaseadaptorTrace(dba, 1);
+    }
+
     return ensDatabaseconnectionEscapeS(dba->Databaseconnection, Pstr, str);
 }
 
@@ -876,32 +957,56 @@ AjBool ensDatabaseadaptorEscapeS(EnsPDatabaseadaptor dba,
 
 AjBool ensDatabaseadaptorTrace(const EnsPDatabaseadaptor dba, ajuint level)
 {
+    AjIList iter = NULL;
+
     AjPStr indent = NULL;
-    
+    AjPStr name = NULL;
+
     if(!dba)
-	return ajFalse;
-    
+        return ajFalse;
+
     indent = ajStrNew();
-    
+
     ajStrAppendCountK(&indent, ' ', level * 2);
-    
+
     ajDebug("%SensDatabaseadaptorTrace %p\n"
-	    "%S  Databaseconnection %p\n"
-	    "%S  Species '%S'\n"
-	    "%S  Group '%s'\n"
-	    "%S  MultiSpecies %B\n"
-	    "%S  Identifier %u\n",
-	    indent, dba,
-	    indent, dba->Databaseconnection,
-	    indent, dba->Species,
-	    indent, ensDatabaseadaptorGroupToChar(dba->Group),
-	    indent, dba->MultiSpecies,
-	    indent, dba->Identifier);
-    
+            "%S  Databaseconnection %p\n"
+            "%S  Species '%S'\n"
+            "%S  SpeciesNames %p\n"
+            "%S  Group '%s'\n"
+            "%S  MultiSpecies %B\n"
+            "%S  Identifier %u\n",
+            indent, dba,
+            indent, dba->Databaseconnection,
+            indent, dba->Species,
+            indent, dba->SpeciesNames,
+            indent, ensDatabaseadaptorGroupToChar(dba->Group),
+            indent, dba->MultiSpecies,
+            indent, dba->Identifier);
+
     ensDatabaseconnectionTrace(dba->Databaseconnection, level + 1);
-    
+
+    /* Trace the AJAX List of species name AJAX Strings. */
+
+    if(dba->SpeciesNames)
+    {
+        ajDebug("%S    AJAX List %p of species name AJAX Strings\n",
+                indent, dba->SpeciesNames);
+
+        iter = ajListIterNewread(dba->SpeciesNames);
+
+        while(!ajListIterDone(iter))
+        {
+            name = (AjPStr) ajListIterGet(iter);
+
+            ajDebug("%S      %S\n", indent, name);
+        }
+
+        ajListIterDel(&iter);
+    }
+
     ajStrDel(&indent);
-    
+
     return ajTrue;
 }
 
@@ -926,40 +1031,76 @@ AjBool ensDatabaseadaptorGetSchemaBuild(const EnsPDatabaseadaptor dba,
 {
     ajuint i = 0;
     ajuint tokens = 0;
-    
+
     AjPStr database = NULL;
     AjPStr temp = NULL;
     AjPStrTok token = NULL;
-    
+
     if(!dba)
-	return ajFalse;
-    
+        return ajFalse;
+
     if(!Pbuild)
-	return ajFalse;
-    
+        return ajFalse;
+
     ajStrAssignClear(Pbuild);
-    
+
     database = ensDatabaseconnectionGetDatabaseName(dba->Databaseconnection);
-    
+
     tokens = ajStrParseCountC(database, "_");
-    
+
     if(tokens < 2)
-	return ajFalse;
-    
+        return ajFalse;
+
     token = ajStrTokenNewC(database, "_");
-    
+
     /* Parse all string tokens but the last two. */
-    
+
     temp = ajStrNew();
-    
+
     for(i = 0; i < (tokens - 2); i++)
-	ajStrTokenNextParse(&token, &temp);
-    
+        ajStrTokenNextParse(&token, &temp);
+
     ajStrDel(&temp);
-    
+
     ajStrTokenRestParse(&token, Pbuild);
-    
+
     ajStrTokenDel(&token);
-    
+
     return ajTrue;
 }
+
+
+
+
+/* @func ensDatabaseadaptorGetAllSpeciesNames *********************************
+**
+** Get the name of all species contained in the database this
+** Ensembl Database Adaptor is connected to.
+**
+** @param [u] dba [EnsPDatabaseadaptor] Ensembl Database Adaptor
+**
+** @return [const AjPList] AJAX List of AJAX Strings
+** @@
+******************************************************************************/
+
+const AjPList ensDatabaseadaptorGetAllSpeciesNames(EnsPDatabaseadaptor dba)
+{
+    EnsPMetainformationadaptor mia = NULL;
+
+    if(!dba)
+        return NULL;
+
+    if(dba->SpeciesNames)
+        return dba->SpeciesNames;
+    else
+        dba->SpeciesNames = ajListstrNew();
+
+    mia = ensRegistryGetMetainformationadaptor(dba);
+
+    if(dba->MultiSpecies)
+        ensMetainformationadaptorFetchAllSpeciesNames(mia, dba->SpeciesNames);
+    else
+        ajListPushAppend(dba->SpeciesNames, (void *) ajStrNewS(dba->Species));
+
+    return dba->SpeciesNames;
+}
