@@ -106,18 +106,18 @@ typedef struct EnsSProteinalignfeatureadaptor
 
 
 
-/******************************************************************************
+/* EnsEBasealignfeatureType ***************************************************
 **
 ** Ensembl Base Align Feature Type enumeration.
 **
 ******************************************************************************/
 
-enum EnsEBasealignfeatureType
+typedef enum EnsOBasealignfeatureType
 {
     ensEBasealignfeatureTypeNULL,
     ensEBasealignfeatureTypeDNA,
     ensEBasealignfeatureTypeProtein
-};
+} EnsEBasealignfeatureType;
 
 
 
@@ -141,7 +141,7 @@ enum EnsEBasealignfeatureType
 ** @cc Bio::EnsEMBL::Basealignfeature
 ** @attr GetFeaturepair [(EnsPFeaturepair*)] Get Ensembl Feature Pair function
 ** @attr Cigar [AjPStr] CIGAR line
-** @attr Type [AjEnum] Type (ensEBasealignfeatureTypeDNA, ...)
+** @attr Type [EnsEBasealignfeatureType] Type
 ** @attr AlignmentLength [ajuint] Target component alignment length
 ** @attr PairDNAAlignFeatureIdentifier [ajuint] Pair DNA Align Feature
 **                                              identifier
@@ -158,7 +158,7 @@ typedef struct EnsSBasealignfeature
     EnsPFeaturepair Featurepair;
     EnsPFeaturepair (*GetFeaturepair)(void* object);
     AjPStr Cigar;
-    AjEnum Type;
+    EnsEBasealignfeatureType Type;
     ajuint AlignmentLength;
     ajuint PairDNAAlignFeatureIdentifier;
     ajuint Padding;
@@ -323,7 +323,7 @@ typedef struct EnsSAssemblyexceptionfeatureadaptor
 ** @attr Feature [EnsPFeature] Ensembl Feature
 ** @cc Bio::EnsEMBL::Assemblyexceptionfeature
 ** @attr AlternateSlice [EnsPSlice] Alternate Ensembl Slice
-** @attr Type [AjEnum] Ensembl Assembly Exception Feature type
+** @attr Type [EnsEAssemblyexceptionType] Ensembl Assembly Exception type
 ** @attr Padding [ajuint] Padding to alignment boundary
 ** @@
 ******************************************************************************/
@@ -335,7 +335,7 @@ typedef struct EnsSAssemblyexceptionfeature
     EnsPAssemblyexceptionfeatureadaptor Adaptor;
     EnsPFeature Feature;
     EnsPSlice AlternateSlice;
-    AjEnum Type;
+    EnsEAssemblyexceptionType Type;
     ajuint Padding;
 } EnsOAssemblyexceptionfeature;
 
@@ -396,7 +396,7 @@ AjBool ensFeatureTrace(const EnsPFeature feature, ajuint level);
 
 ajuint ensFeatureGetLength(const EnsPFeature feature);
 
-ajuint ensFeatureGetMemSize(const EnsPFeature feature);
+ajulong ensFeatureGetMemsize(const EnsPFeature feature);
 
 const EnsPSeqregion ensFeatureGetSeqregion(const EnsPFeature feature);
 
@@ -418,7 +418,7 @@ AjBool ensFeatureMove(EnsPFeature feature,
 AjBool ensFeatureProject(const EnsPFeature feature,
                          const AjPStr csname,
                          const AjPStr csversion,
-                         AjPList pslist);
+                         AjPList pss);
 
 EnsPFeature ensFeatureTransform(EnsPFeature feature,
                                 const AjPStr csname,
@@ -430,6 +430,19 @@ AjBool ensFeatureFetchAllAlternativeLocations(EnsPFeature feature,
                                               AjBool all,
                                               AjPList features);
 
+int ensFeatureCompareStartAscending(const EnsPFeature feature1,
+                                    const EnsPFeature feature2);
+
+int ensFeatureCompareStartDescending(const EnsPFeature feature1,
+                                     const EnsPFeature feature2);
+
+AjBool ensFeatureSortByStartAscending(AjPList features);
+
+AjBool ensFeatureSortByStartDescending(AjPList features);
+
+AjBool ensFeatureMatch(const EnsPFeature feature1,
+                       const EnsPFeature feature2);
+
 AjBool ensFeatureOverlap(const EnsPFeature feature1,
                          const EnsPFeature feature2);
 
@@ -441,75 +454,74 @@ EnsPFeatureadaptor ensFeatureadaptorNew(
     EnsPDatabaseadaptor dba,
     const char **Ptables,
     const char **Pcolumns,
-    EnsOBaseadaptorLeftJoin *left_join,
+    EnsOBaseadaptorLeftJoin *leftjoin,
     const char *condition,
     const char *final,
     AjBool Fquery(EnsPDatabaseadaptor dba,
                   const AjPStr statement,
-                  EnsPAssemblymapper mapper,
+                  EnsPAssemblymapper am,
                   EnsPSlice slice,
                   AjPList objects),
     void* Fread(const void* key),
     void* Freference(void* value),
     AjBool Fwrite(const void* value),
     void Fdelete(void** value),
-    ajuint Fsize(const void* value),
+    ajulong Fsize(const void* value),
     EnsPFeature Fgetfeature(const void *object),
     const char *label);
 
-void ensFeatureadaptorDel(EnsPFeatureadaptor *Padaptor);
+void ensFeatureadaptorDel(EnsPFeatureadaptor *Pfa);
 
-EnsPBaseadaptor ensFeatureadaptorGetBaseadaptor(
-    const EnsPFeatureadaptor adaptor);
+EnsPBaseadaptor ensFeatureadaptorGetBaseadaptor(const EnsPFeatureadaptor fa);
 
-EnsPCache ensFeatureadaptorGetCache(const EnsPFeatureadaptor adaptor);
+EnsPCache ensFeatureadaptorGetCache(const EnsPFeatureadaptor fa);
 
-ajuint ensFeatureadaptorGetMaxFeatureLength(const EnsPFeatureadaptor adaptor);
+ajuint ensFeatureadaptorGetMaxFeatureLength(const EnsPFeatureadaptor fa);
 
 EnsPDatabaseadaptor ensFeatureadaptorGetDatabaseadaptor(
-    const EnsPFeatureadaptor adaptor);
+    const EnsPFeatureadaptor fa);
 
-AjBool ensFeatureadaptorSetMaximumFeatureLength(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorSetMaximumFeatureLength(EnsPFeatureadaptor fa,
                                                 ajuint length);
 
-AjBool ensFeatureadaptorSetTables(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorSetTables(EnsPFeatureadaptor fa,
                                   const char **Ptables);
 
-AjBool ensFeatureadaptorSetColumns(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorSetColumns(EnsPFeatureadaptor fa,
                                    const char **Pcolumns);
 
-AjBool ensFeatureadaptorSetDefaultCondition(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorSetDefaultCondition(EnsPFeatureadaptor fa,
                                             const char *condition);
 
-AjBool ensFeatureadaptorSetFinalCondition(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorSetFinalCondition(EnsPFeatureadaptor fa,
                                           const char *final);
 
-AjBool ensFeatureadaptorEscapeC(EnsPFeatureadaptor adaptor,
-                                 char **Ptxt,
-                                 const AjPStr str);
+AjBool ensFeatureadaptorEscapeC(EnsPFeatureadaptor fa,
+                                char **Ptxt,
+                                const AjPStr str);
 
-AjBool ensFeatureadaptorEscapeS(EnsPFeatureadaptor adaptor,
-                                 AjPStr *Pstr,
-                                 const AjPStr str);
+AjBool ensFeatureadaptorEscapeS(EnsPFeatureadaptor fa,
+                                AjPStr *Pstr,
+                                const AjPStr str);
 
-AjBool ensFeatureadaptorFetchAllBySliceConstraint(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorFetchAllBySliceConstraint(EnsPFeatureadaptor fa,
                                                   EnsPSlice slice,
                                                   const AjPStr constraint,
                                                   const AjPStr anname,
                                                   AjPList objects);
 
-AjBool ensFeatureadaptorFetchAllBySlice(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorFetchAllBySlice(EnsPFeatureadaptor fa,
                                         EnsPSlice slice,
                                         const AjPStr anname,
                                         AjPList objects);
 
-AjBool ensFeatureadaptorFetchAllBySliceScore(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorFetchAllBySliceScore(EnsPFeatureadaptor fa,
                                              EnsPSlice slice,
                                              double score,
                                              const AjPStr anname,
                                              AjPList objects);
 
-AjBool ensFeatureadaptorFetchAllByAnalysisName(EnsPFeatureadaptor adaptor,
+AjBool ensFeatureadaptorFetchAllByAnalysisName(EnsPFeatureadaptor fa,
                                                const AjPStr anname,
                                                AjPList objects);
 
@@ -591,7 +603,7 @@ AjBool ensFeaturepairTrace(const EnsPFeaturepair fp, ajuint level);
 
 AjBool ensFeaturepairSetSequenceIdentity(EnsPFeaturepair fp, float identity);
 
-ajuint ensFeaturepairGetMemSize(const EnsPFeaturepair fp);
+ajulong ensFeaturepairGetMemsize(const EnsPFeaturepair fp);
 
 EnsPFeaturepair ensFeaturepairTransform(const EnsPFeaturepair fp,
                                         const AjPStr csname,
@@ -599,17 +611,27 @@ EnsPFeaturepair ensFeaturepairTransform(const EnsPFeaturepair fp,
 
 EnsPFeaturepair ensFeaturepairTransfer(EnsPFeaturepair fp, EnsPSlice slice);
 
+int ensFeaturepairCompareSourceFeatureStartAscending(const void* P1,
+                                                     const void* P2);
+
+int ensFeaturepairCompareSourceFeatureStartDescending(const void* P1,
+                                                      const void* P2);
+
+AjBool ensFeaturepairSortBySourceFeatureStartAscending(AjPList fps);
+
+AjBool ensFeaturepairSortBySourceFeatureStartDescending(AjPList fps);
+
 /* Ensembl Base Align Feature */
 
 EnsPBasealignfeature ensBasealignfeatureNewD(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     ajuint identifier,
     EnsPFeaturepair fp,
     AjPStr cigar,
     ajuint pair);
 
 EnsPBasealignfeature ensBasealignfeatureNewP(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     ajuint identifier,
     EnsPFeaturepair fp,
     AjPStr cigar);
@@ -618,7 +640,7 @@ EnsPBasealignfeature ensBasealignfeatureNew(
     EnsPFeaturepair fp,
     AjPStr cigar,
     AjPList fps,
-    AjEnum type,
+    EnsEBasealignfeatureType type,
     ajuint pair);
 
 EnsPBasealignfeature ensBasealignfeatureNewObj(
@@ -652,7 +674,7 @@ ajuint ensBasealignfeatureGetSourceUnit(const EnsPBasealignfeature baf);
 
 ajuint ensBasealignfeatureGetTargetUnit(const EnsPBasealignfeature baf);
 
-ajuint ensBasealignfeatureGetMemSize(const EnsPBasealignfeature baf);
+ajulong ensBasealignfeatureGetMemsize(const EnsPBasealignfeature baf);
 
 EnsPBasealignfeature ensBasealignfeatureTransform(
     const EnsPBasealignfeature baf,
@@ -667,108 +689,118 @@ AjBool ensBasealignfeatureTrace(const EnsPBasealignfeature baf, ajuint level);
 AjBool ensBasealignfeatureFetchAllFeaturepairs(const EnsPBasealignfeature baf,
                                                AjPList fps);
 
+AjBool ensBasealignfeatureSortBySourceFeatureStartAscending(AjPList bafs);
+
+AjBool ensBasealignfeatureSortBySourceFeatureStartDescending(AjPList bafs);
+
 /* Ensembl DNA Align Feature Adaptor */
 
+EnsPDNAAlignFeatureadaptor ensRegistryGetDNAAlignFeatureadaptor(
+    EnsPDatabaseadaptor dba);
+
 EnsPDNAAlignFeatureadaptor ensDNAAlignFeatureadaptorNew(
     EnsPDatabaseadaptor dba);
 
-void ensDNAAlignFeatureadaptorDel(EnsPDNAAlignFeatureadaptor *Padaptor);
+void ensDNAAlignFeatureadaptorDel(EnsPDNAAlignFeatureadaptor *Pdafa);
 
 AjBool ensDNAAlignFeatureadaptorFetchByIdentifier(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     ajuint identifier,
     EnsPBasealignfeature *Pbaf);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllBySliceIdentity(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     EnsPSlice slice,
     float identity,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllBySliceCoverage(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     EnsPSlice slice,
     float coverage,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllBySliceExternaldatabase(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     EnsPSlice slice,
     const AjPStr edbname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllByHitName(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     const AjPStr hitname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllByHitUnversioned(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     const AjPStr hitname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensDNAAlignFeatureadaptorFetchAllIdentifiers(
-    EnsPDNAAlignFeatureadaptor adaptor,
+    EnsPDNAAlignFeatureadaptor dafa,
     AjPList idlist);
 
 /* Ensembl Protein Align Feature Adaptor */
 
+EnsPProteinalignfeatureadaptor ensRegistryGetProteinalignfeatureadaptor(
+    EnsPDatabaseadaptor dba);
+
 EnsPProteinalignfeatureadaptor ensProteinalignfeatureadaptorNew(
     EnsPDatabaseadaptor dba);
 
-void ensProteinalignfeatureadaptorDel(EnsPProteinalignfeatureadaptor *Padaptor);
+void ensProteinalignfeatureadaptorDel(EnsPProteinalignfeatureadaptor *Ppafa);
 
 AjBool ensProteinalignfeatureadaptorFetchByIdentifier(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     ajuint identifier,
     EnsPBasealignfeature *Pbaf);
 
 AjBool ensProteinalignfeatureadaptorFetchAllBySliceIdentity(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     EnsPSlice slice,
     float identity,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensProteinalignfeatureadaptorFetchAllBySliceCoverage(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     EnsPSlice slice,
     float coverage,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensProteinalignfeatureadaptorFetchAllBySliceExternaldatabase(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     EnsPSlice slice,
     const AjPStr edbname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensProteinalignfeatureadaptorFetchAllByHitName(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     const AjPStr hitname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensProteinalignfeatureadaptorFetchAllByHitUnversioned(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     const AjPStr hitname,
     const AjPStr anname,
     AjPList bafs);
 
 AjBool ensProteinalignfeatureadaptorFetchAllIdentifiers(
-    EnsPProteinalignfeatureadaptor adaptor,
+    EnsPProteinalignfeatureadaptor pafa,
     AjPList idlist);
 
 /* Ensembl Protein Feature */
 
 EnsPProteinfeature ensProteinfeatureNew(
-    EnsPProteinfeatureadaptor adaptor,
+    EnsPProteinfeatureadaptor pfa,
     ajuint identifier,
     EnsPFeaturepair fp,
     AjPStr accession,
@@ -792,7 +824,7 @@ AjPStr ensProteinfeatureGetAccession(const EnsPProteinfeature pf);
 AjPStr ensProteinfeatureGetDescription(const EnsPProteinfeature pf);
 
 AjBool ensProteinfeatureSetAdaptor(EnsPProteinfeature pf,
-                                   EnsPProteinfeatureadaptor adaptor);
+                                   EnsPProteinfeatureadaptor pfa);
 
 AjBool ensProteinfeatureSetIdentifier(EnsPProteinfeature pf, ajuint identifier);
 
@@ -806,27 +838,31 @@ AjBool ensProteinfeatureSetDescription(EnsPProteinfeature pf,
 
 AjBool ensProteinfeatureTrace(const EnsPProteinfeature pf, ajuint level);
 
-ajuint ensProteinfeatureGetMemSize(const EnsPProteinfeature pf);
+ajulong ensProteinfeatureGetMemsize(const EnsPProteinfeature pf);
 
 /* Ensembl Protein Feature Adaptor */
 
-EnsPProteinfeatureadaptor ensProteinfeatureadaptorNew(EnsPDatabaseadaptor dba);
+EnsPProteinfeatureadaptor ensRegistryGetProteinfeatureadaptor(
+    EnsPDatabaseadaptor dba);
 
-void ensProteinfeatureadaptorDel(EnsPProteinfeatureadaptor *Padaptor);
+EnsPProteinfeatureadaptor ensProteinfeatureadaptorNew(
+    EnsPDatabaseadaptor dba);
+
+void ensProteinfeatureadaptorDel(EnsPProteinfeatureadaptor *Ppfa);
 
 AjBool ensProteinfeatureadaptorFetchAllByTranslationIdentifier(
-    EnsPProteinfeatureadaptor adaptor,
+    EnsPProteinfeatureadaptor pfa,
     ajuint tlid,
     AjPList pfs);
 
 AjBool ensProteinfeatureadaptorFetchByIdentifier(
-    EnsPProteinfeatureadaptor adaptor,
+    EnsPProteinfeatureadaptor pfa,
     ajuint identifier,
     EnsPProteinfeature *Ppf);
 
 /* Ensembl Simple Feature */
 
-EnsPSimplefeature ensSimplefeatureNew(EnsPSimplefeatureadaptor adaptor,
+EnsPSimplefeature ensSimplefeatureNew(EnsPSimplefeatureadaptor pfa,
                                       ajuint identifier,
                                       EnsPFeature feature,
                                       AjPStr label,
@@ -849,7 +885,7 @@ AjPStr ensSimplefeatureGetDisplayLabel(const EnsPSimplefeature sf);
 double ensSimplefeatureGetScore(const EnsPSimplefeature sf);
 
 AjBool ensSimplefeatureSetAdaptor(EnsPSimplefeature sf,
-                                  EnsPSimplefeatureadaptor adaptor);
+                                  EnsPSimplefeatureadaptor sfa);
 
 AjBool ensSimplefeatureSetIdentifier(EnsPSimplefeature sf, ajuint identifier);
 
@@ -861,39 +897,47 @@ AjBool ensSimplefeatureSetScore(EnsPSimplefeature sf, double score);
 
 AjBool ensSimplefeatureTrace(const EnsPSimplefeature sf, ajuint level);
 
-ajuint ensSimplefeatureGetMemSize(const EnsPSimplefeature sf);
+ajulong ensSimplefeatureGetMemsize(const EnsPSimplefeature sf);
+
+AjBool ensSimplefeatureSortByStartAscending(AjPList sfs);
+
+AjBool ensSimplefeatureSortByStartDescending(AjPList sfs);
 
 /* Ensembl Simple Feature Adaptor */
 
-EnsPSimplefeatureadaptor ensSimplefeatureadaptorNew(EnsPDatabaseadaptor dba);
+EnsPSimplefeatureadaptor ensRegistryGetSimplefeatureadaptor(
+    EnsPDatabaseadaptor dba);
 
-void ensSimplefeatureadaptorDel(EnsPSimplefeatureadaptor *Padaptor);
+EnsPSimplefeatureadaptor ensSimplefeatureadaptorNew(
+    EnsPDatabaseadaptor dba);
 
-AjBool ensSimplefeatureadaptorFetchAllBySlice(EnsPSimplefeatureadaptor adaptor,
+void ensSimplefeatureadaptorDel(EnsPSimplefeatureadaptor *Psfa);
+
+AjBool ensSimplefeatureadaptorFetchAllBySlice(EnsPSimplefeatureadaptor sfa,
                                               EnsPSlice slice,
                                               const AjPStr anname,
                                               AjPList sfs);
 
 AjBool ensSimplefeatureadaptorFetchAllBySliceScore(
-    EnsPSimplefeatureadaptor adaptor,
+    EnsPSimplefeatureadaptor sfa,
     EnsPSlice slice,
     double score,
     const AjPStr anname,
     AjPList sfs);
 
 AjBool ensSimplefeatureadaptorFetchAllByAnalysisName(
-    EnsPSimplefeatureadaptor adaptor,
+    EnsPSimplefeatureadaptor sfa,
     const AjPStr anname,
     AjPList sfs);
 
 /* Ensembl Assembly Exception Feature */
 
 EnsPAssemblyexceptionfeature ensAssemblyexceptionfeatureNew(
-    EnsPAssemblyexceptionfeatureadaptor adaptor,
+    EnsPAssemblyexceptionfeatureadaptor aefa,
     ajuint identifier,
     EnsPFeature feature,
     EnsPSlice slice,
-    AjEnum type);
+    EnsEAssemblyexceptionType type);
 
 EnsPAssemblyexceptionfeature ensAssemblyexceptionfeatureNewObj(
     const EnsPAssemblyexceptionfeature object);
@@ -915,12 +959,12 @@ EnsPFeature ensAssemblyexceptionfeatureGetFeature(
 EnsPSlice ensAssemblyexceptionfeatureGetAlternateSlice(
     const EnsPAssemblyexceptionfeature aef);
 
-AjEnum ensAssemblyexceptionfeatureGetType(
+EnsEAssemblyexceptionType ensAssemblyexceptionfeatureGetType(
     const EnsPAssemblyexceptionfeature aef);
 
 AjBool ensAssemblyexceptionfeatureSetAdaptor(
     EnsPAssemblyexceptionfeature aef,
-    EnsPAssemblyexceptionfeatureadaptor adaptor);
+    EnsPAssemblyexceptionfeatureadaptor aefa);
 
 AjBool ensAssemblyexceptionfeatureSetIdentifier(
     EnsPAssemblyexceptionfeature aef,
@@ -934,7 +978,7 @@ AjBool ensAssemblyexceptionfeatureSetAlternateSlice(
     EnsPSlice altslice);
 
 AjBool ensAssemblyexceptionfeatureSetType(EnsPAssemblyexceptionfeature aef,
-                                          AjEnum type);
+                                          EnsEAssemblyexceptionType type);
 
 AjBool ensAssemblyexceptionfeatureFetchDisplayIdentifier(
     const EnsPAssemblyexceptionfeature aef,
@@ -945,23 +989,26 @@ AjBool ensAssemblyexceptionfeatureTrace(const EnsPAssemblyexceptionfeature aef,
 
 /* Ensembl Assembly Exception Feature Adaptor */
 
+EnsPAssemblyexceptionfeatureadaptor ensRegistryGetAssemblyexceptionfeatureadaptor(
+    EnsPDatabaseadaptor dba);
+
 EnsPAssemblyexceptionfeatureadaptor ensAssemblyexceptionfeatureadaptorNew(
     EnsPDatabaseadaptor dba);
 
 void ensAssemblyexceptionfeatureadaptorDel(
-    EnsPAssemblyexceptionfeatureadaptor* Padaptor);
+    EnsPAssemblyexceptionfeatureadaptor* Paefa);
 
 AjBool ensAssemblyexceptionfeatureadaptorFetchAll(
-    EnsPAssemblyexceptionfeatureadaptor adaptor,
+    EnsPAssemblyexceptionfeatureadaptor aefa,
     AjPList aefs);
 
 AjBool ensAssemblyexceptionfeatureadaptorFetchByIdentifier(
-    EnsPAssemblyexceptionfeatureadaptor adaptor,
+    EnsPAssemblyexceptionfeatureadaptor aefa,
     ajuint identifier,
     EnsPAssemblyexceptionfeature* Paef);
 
 AjBool ensAssemblyexceptionfeatureadaptorFetchAllBySlice(
-    EnsPAssemblyexceptionfeatureadaptor adaptor,
+    EnsPAssemblyexceptionfeatureadaptor aefa,
     EnsPSlice slice,
     AjPList aefs);
 
@@ -972,7 +1019,7 @@ AjBool ensAssemblyexceptionfeatureadaptorFetchAllBySlice(
 
 
 
-#endif
+#endif /* ensfeature_h */
 
 #ifdef __cplusplus
 }
