@@ -13,7 +13,7 @@ extern "C"
 
 
 
-/******************************************************************************
+/* EnsPQcdasfeatureadaptor ****************************************************
 **
 ** Ensembl QC DAS Feature Adaptor
 **
@@ -24,13 +24,13 @@ extern "C"
 
 
 
-/******************************************************************************
+/* EnsEQcdasfeatureCategory ***************************************************
 **
 ** Ensembl QC DAS Feature Category enumeration
 **
 ******************************************************************************/
 
-enum EnsEQcdasfeatureCategory
+typedef enum EnsOQcdasfeatureCategory
 {
     ensEQcdasfeatureCategoryNULL,
     ensEQcdasfeatureCategoryUnknown,
@@ -44,18 +44,18 @@ enum EnsEQcdasfeatureCategory
     ensEQcdasfeatureCategoryTranslationPartial,
     ensEQcdasfeatureCategoryTranslationMissing,
     ensEQcdasfeatureCategoryTranslation
-};
+} EnsEQcdasfeatureCategory;
 
 
 
 
-/******************************************************************************
+/* EnsEQcdasfeatureType *******************************************************
 **
 ** Ensembl QC DAS Feature Type enumeration
 **
 ******************************************************************************/
 
-enum EnsEQcdasfeatureType
+typedef enum EnsOQcdasfeatureType
 {
     ensEQcdasfeatureTypeNULL,
     ensEQcdasfeatureTypeUnknown,
@@ -65,7 +65,7 @@ enum EnsEQcdasfeatureType
     ensEQcdasfeatureTypeExonFrameshift,
     ensEQcdasfeatureTypeExonGap,
     ensEQcdasfeatureTypeExon
-};
+} EnsEQcdasfeatureType;
 
 
 
@@ -93,8 +93,8 @@ enum EnsEQcdasfeatureType
 ** @attr FeatureStart [ajuint] Feature start
 ** @attr FeatureEnd [ajuint] Feature end
 ** @attr Phase [ajint] Phase
-** @attr Category [AjEnum] Category
-** @attr Type [AjEnum] Type
+** @attr Category [EnsEQcdasfeatureCategory] Category
+** @attr Type [EnsEQcdasfeatureType] Type
 ** @@
 ******************************************************************************/
 
@@ -113,8 +113,8 @@ typedef struct EnsSQcdasfeature
     ajuint FeatureStart;
     ajuint FeatureEnd;
     ajint Phase;
-    AjEnum Category;
-    AjEnum Type;
+    EnsEQcdasfeatureCategory Category;
+    EnsEQcdasfeatureType Type;
 } EnsOQcdasfeature;
 
 #define EnsPQcdasfeature EnsOQcdasfeature*
@@ -122,7 +122,7 @@ typedef struct EnsSQcdasfeature
 
 
 
-/******************************************************************************
+/* EnsPQcvariationadaptor *****************************************************
 **
 ** Ensembl QC Variation Adaptor
 **
@@ -133,48 +133,48 @@ typedef struct EnsSQcdasfeature
 
 
 
-/******************************************************************************
+/* EnsEQcvariationClass *******************************************************
 **
 ** Ensembl QC Variation Class enumeration
 **
 ******************************************************************************/
 
-enum EnsEQcvariationClass
+typedef enum EnsOQcvariationClass
 {
     ensEQcvariationClassNULL,
     ensEQcvariationClassNone,
     ensEQcvariationClassSimple,
     ensEQcvariationClassSplice,
     ensEQcvariationClassExon
-};
+} EnsEQcvariationClass;
 
 
 
 
-/******************************************************************************
+/* EnsEQcvariationType ********************************************************
 **
 ** Ensembl QC Variation Type enumeration
 **
 ******************************************************************************/
 
-enum EnsEQcvariationType
+typedef enum EnsOQcvariationType
 {
     ensEQcvariationTypeNULL,
     ensEQcvariationTypeNone,
     ensEQcvariationTypeSingle,
     ensEQcvariationTypeMulti
-};
+} EnsEQcvariationType;
 
 
 
 
-/******************************************************************************
+/* EnsEQcvariationState *******************************************************
 **
 ** Ensembl QC Variation State enumeration
 **
 ******************************************************************************/
 
-enum EnsEQcvariationState
+typedef enum EnsOQcvariationState
 {
     ensEQcvariationStateNULL,
     ensEQcvariationStateNone,
@@ -184,7 +184,7 @@ enum EnsEQcvariationState
     ensEQcvariationState5ss,
     ensEQcvariationState3ss,
     EnsEQcvariationStateSplit
-};
+} EnsEQcvariationState;
 
 
 
@@ -212,9 +212,9 @@ enum EnsEQcvariationState
 ** @attr TargetStart [ajuint] Target start
 ** @attr TargetEnd [ajuint] Target end
 ** @attr TargetString [AjPStr] Target string
-** @attr Class [AjEnum] Class
-** @attr Type [AjEnum] Type
-** @attr State [AjEnum] State
+** @attr Class [EnsEQcvariationClass] Class
+** @attr Type [EnsEQcvariationType] Type
+** @attr State [EnsEQcvariationState] State
 ** @attr Padding [char[4]] Padding to alignment boundary
 ** @@
 ******************************************************************************/
@@ -234,9 +234,9 @@ typedef struct EnsSQcvariation
     ajuint TargetStart;
     ajuint TargetEnd;
     AjPStr TargetString;
-    AjEnum Class;
-    AjEnum Type;
-    AjEnum State;
+    EnsEQcvariationClass Class;
+    EnsEQcvariationType Type;
+    EnsEQcvariationState State;
     char Padding[4];
 } EnsOQcvariation;
 
@@ -245,7 +245,7 @@ typedef struct EnsSQcvariation
 
 
 
-/******************************************************************************
+/* EnsPQcsubmissionadaptor ****************************************************
 **
 ** Ensembl QC Submission Adaptor
 **
@@ -312,20 +312,20 @@ typedef struct EnsSQcsubmission
 
 /* Ensembl Quality Check DAS Feature */
 
-EnsPQcdasfeature ensQcdasfeatureNew(EnsPQcdasfeatureadaptor adaptor,
+EnsPQcdasfeature ensQcdasfeatureNew(EnsPQcdasfeatureadaptor qcdasfa,
                                     ajuint identifier,
                                     EnsPQcalignment qca,
                                     EnsPAnalysis analysis,
                                     EnsPQcsequence segment,
-                                    ajuint sstart,
-                                    ajuint send,
-                                    ajint sstrand,
+                                    ajuint segstart,
+                                    ajuint segend,
+                                    ajint segstrand,
                                     EnsPQcsequence feature,
                                     ajuint fstart,
                                     ajuint fend,
                                     ajint phase,
-                                    AjEnum category,
-                                    AjEnum type);
+                                    EnsEQcdasfeatureCategory category,
+                                    EnsEQcdasfeatureType type);
 
 EnsPQcdasfeature ensQcdasfeatureNewObj(const EnsPQcdasfeature object);
 
@@ -336,36 +336,49 @@ void ensQcdasfeatureDel(EnsPQcdasfeature* Pqcdasf);
 EnsPQcdasfeatureadaptor ensQcdasfeatureGetAdaptor(
     const EnsPQcdasfeature qcdasf);
 
-ajuint ensQcdasfeatureGetIdentifier(const EnsPQcdasfeature qcdasf);
+ajuint ensQcdasfeatureGetIdentifier(
+    const EnsPQcdasfeature qcdasf);
 
-EnsPQcalignment ensQcdasfeatureGetQcalignment(const EnsPQcdasfeature qcdasf);
+EnsPQcalignment ensQcdasfeatureGetQcalignment(
+    const EnsPQcdasfeature qcdasf);
 
-EnsPAnalysis ensQcdasfeatureGetAnalysis(const EnsPQcdasfeature qcdasf);
+EnsPAnalysis ensQcdasfeatureGetAnalysis(
+    const EnsPQcdasfeature qcdasf);
 
-EnsPQcsequence ensQcdasfeatureGetSegmentSequence(const EnsPQcdasfeature qcdasf);
+EnsPQcsequence ensQcdasfeatureGetSegmentSequence(
+    const EnsPQcdasfeature qcdasf);
 
-EnsPQcsequence ensQcdasfeatureGetFeatureSequence(const EnsPQcdasfeature qcdasf);
+EnsPQcsequence ensQcdasfeatureGetFeatureSequence(
+    const EnsPQcdasfeature qcdasf);
 
-ajuint ensQcdasfeatureGetSegmentStart(const EnsPQcdasfeature qcdasf);
+ajuint ensQcdasfeatureGetSegmentStart(
+    const EnsPQcdasfeature qcdasf);
 
-ajuint ensQcdasfeatureGetSegmentEnd(const EnsPQcdasfeature qcdasf);
+ajuint ensQcdasfeatureGetSegmentEnd(
+    const EnsPQcdasfeature qcdasf);
 
-ajint ensQcdasfeatureGetSegmentStrand(const EnsPQcdasfeature qcdasf);
+ajint ensQcdasfeatureGetSegmentStrand(
+    const EnsPQcdasfeature qcdasf);
 
-ajuint ensQcdasfeatureGetFeatureStart(const EnsPQcdasfeature qcdasf);
+ajuint ensQcdasfeatureGetFeatureStart(
+    const EnsPQcdasfeature qcdasf);
 
-ajuint ensQcdasfeatureGetFeatureEnd(const EnsPQcdasfeature qcdasf);
+ajuint ensQcdasfeatureGetFeatureEnd(
+    const EnsPQcdasfeature qcdasf);
 
-ajint ensQcdasfeatureGetPhase(const EnsPQcdasfeature qcdasf);
+ajint ensQcdasfeatureGetPhase(
+    const EnsPQcdasfeature qcdasf);
 
-AjEnum ensQcdasfeatureGetCategory(const EnsPQcdasfeature qcdasf);
+EnsEQcdasfeatureCategory ensQcdasfeatureGetCategory(
+    const EnsPQcdasfeature qcdasf);
 
-AjEnum ensQcdasfeatureGetType(const EnsPQcdasfeature qcdasf);
+EnsEQcdasfeatureType ensQcdasfeatureGetType(const EnsPQcdasfeature qcdasf);
 
 AjBool ensQcdasfeatureSetAdaptor(EnsPQcdasfeature qcdasf,
-                                 EnsPQcdasfeatureadaptor adaptor);
+                                 EnsPQcdasfeatureadaptor qcdasfa);
 
-AjBool ensQcdasfeatureSetIdentifier(EnsPQcdasfeature qcdasf, ajuint identifier);
+AjBool ensQcdasfeatureSetIdentifier(EnsPQcdasfeature qcdasf,
+                                    ajuint identifier);
 
 AjBool ensQcdasfeatureSetQcalignment(EnsPQcdasfeature qcdasf,
                                      EnsPQcalignment qca);
@@ -379,71 +392,88 @@ AjBool ensQcdasfeatureSetSegmentSequence(EnsPQcdasfeature qcdasf,
 AjBool ensQcdasfeatureSetFeatureSequence(EnsPQcdasfeature qcdasf,
                                          EnsPQcsequence qcs);
 
-AjBool ensQcdasfeatureSetSegmentStart(EnsPQcdasfeature qcdasf, ajuint start);
+AjBool ensQcdasfeatureSetSegmentStart(EnsPQcdasfeature qcdasf,
+                                      ajuint start);
 
-AjBool ensQcdasfeatureSetSegmentEnd(EnsPQcdasfeature qcdasf, ajuint end);
+AjBool ensQcdasfeatureSetSegmentEnd(EnsPQcdasfeature qcdasf,
+                                    ajuint end);
 
-AjBool ensQcdasfeatureSetSegmentStrand(EnsPQcdasfeature qcdasf, ajint strand);
+AjBool ensQcdasfeatureSetSegmentStrand(EnsPQcdasfeature qcdasf,
+                                       ajint strand);
 
-AjBool ensQcdasfeatureSetFeatureStart(EnsPQcdasfeature qcdasf, ajuint start);
+AjBool ensQcdasfeatureSetFeatureStart(EnsPQcdasfeature qcdasf,
+                                      ajuint start);
 
-AjBool ensQcdasfeatureSetFeatureEnd(EnsPQcdasfeature qcdasf, ajuint end);
+AjBool ensQcdasfeatureSetFeatureEnd(EnsPQcdasfeature qcdasf,
+                                    ajuint end);
 
-AjBool ensQcdasfeatureSetPhase(EnsPQcdasfeature qcdasf, ajint phase);
+AjBool ensQcdasfeatureSetPhase(EnsPQcdasfeature qcdasf,
+                               ajint phase);
 
-AjBool ensQcdasfeatureSetCategory(EnsPQcdasfeature qcdasf, AjEnum category);
+AjBool ensQcdasfeatureSetCategory(EnsPQcdasfeature qcdasf,
+                                  EnsEQcdasfeatureCategory category);
 
-AjBool ensQcdasfeatureSetType(EnsPQcdasfeature qcdasf, AjEnum type);
+AjBool ensQcdasfeatureSetType(EnsPQcdasfeature qcdasf,
+                              EnsEQcdasfeatureType type);
 
-ajuint ensQcdasfeatureGetMemSize(const EnsPQcdasfeature qcdasf);
+ajulong ensQcdasfeatureGetMemsize(const EnsPQcdasfeature qcdasf);
 
 AjBool ensQcdasfeatureTrace(const EnsPQcdasfeature qcdasf, ajuint level);
 
-AjEnum ensQcdasfeatureCategoryFromStr(const AjPStr category);
+EnsEQcdasfeatureCategory ensQcdasfeatureCategoryFromStr(const AjPStr category);
 
-AjEnum ensQcdasfeatureTypeFromStr(const AjPStr type);
+EnsEQcdasfeatureType ensQcdasfeatureTypeFromStr(const AjPStr type);
 
-const char *ensQcdasfeatureCategoryToChar(const AjEnum category);
+const char *ensQcdasfeatureCategoryToChar(EnsEQcdasfeatureCategory category);
 
-const char *ensQcdasfeatureTypeToChar(const AjEnum type);
+const char *ensQcdasfeatureTypeToChar(EnsEQcdasfeatureType type);
 
 /* Ensembl Quality Check DAS Feature Adaptor */
 
-EnsPQcdasfeatureadaptor ensQcdasfeatureadaptorNew(EnsPDatabaseadaptor dba);
+EnsPQcdasfeatureadaptor ensRegistryGetQcdasfeatureadaptor(
+    EnsPDatabaseadaptor dba);
+
+EnsPQcdasfeatureadaptor ensQcdasfeatureadaptorNew(
+    EnsPDatabaseadaptor dba);
 
 void ensQcdasfeatureadaptorDel(EnsPQcdasfeatureadaptor *Pqcdasfa);
 
-AjBool ensQcdasfeatureadaptorFetchByIdentifier(EnsPQcdasfeatureadaptor adaptor,
-                                               ajuint identifier,
-                                               EnsPQcdasfeature *Pqcdasf);
+AjBool ensQcdasfeatureadaptorFetchByIdentifier(
+    EnsPQcdasfeatureadaptor qcdasfa,
+    ajuint identifier,
+    EnsPQcdasfeature *Pqcdasf);
 
 AjBool ensQcdasfeatureadaptorFetchAllByQcalignment(
     EnsPQcdasfeatureadaptor qcdasfa,
     const EnsPQcalignment qca,
     AjPList qcdasfs);
 
-AjBool ensQcdasfeatureadaptorFetchAllByFeature(EnsPQcdasfeatureadaptor qcdasfa,
-                                               const EnsPAnalysis analysis,
-                                               const EnsPQcsequence feature,
-                                               AjPList qcdasfs);
+AjBool ensQcdasfeatureadaptorFetchAllByFeature(
+    EnsPQcdasfeatureadaptor qcdasfa,
+    const EnsPAnalysis analysis,
+    const EnsPQcsequence feature,
+    AjPList qcdasfs);
 
-AjBool ensQcdasfeatureadaptorFetchAllBySegment(EnsPQcdasfeatureadaptor qcdasfa,
-                                               const EnsPAnalysis analysis,
-                                               const EnsPQcsequence segment,
-                                               AjPList qcdasfs);
+AjBool ensQcdasfeatureadaptorFetchAllBySegment(
+    EnsPQcdasfeatureadaptor qcdasfa,
+    const EnsPAnalysis analysis,
+    const EnsPQcsequence segment,
+    AjPList qcdasfs);
 
-AjBool ensQcdasfeatureadaptorFetchAllByAFS(EnsPQcdasfeatureadaptor qcdasfa,
-                                           const EnsPAnalysis analysis,
-                                           const EnsPQcsequence feature,
-                                           const EnsPQcsequence segment,
-                                           AjPList qcdasfs);
+AjBool ensQcdasfeatureadaptorFetchAllByAFS(
+    EnsPQcdasfeatureadaptor qcdasfa,
+    const EnsPAnalysis analysis,
+    const EnsPQcsequence feature,
+    const EnsPQcsequence segment,
+    AjPList qcdasfs);
 
-AjBool ensQcdasfeatureadaptorFetchAllByRegion(EnsPQcdasfeatureadaptor qcdasfa,
-                                              const EnsPAnalysis analysis,
-                                              const EnsPQcsequence segment,
-                                              ajuint start,
-                                              ajuint end,
-                                              AjPList qcdasfs);
+AjBool ensQcdasfeatureadaptorFetchAllByRegion(
+    EnsPQcdasfeatureadaptor qcdasfa,
+    const EnsPAnalysis analysis,
+    const EnsPQcsequence segment,
+    ajuint start,
+    ajuint end,
+    AjPList qcdasfs);
 
 AjBool ensQcdasfeatureadaptorStore(EnsPQcdasfeatureadaptor qcdasfa,
                                    EnsPQcdasfeature qcdasf);
@@ -452,7 +482,7 @@ AjBool ensQcdasfeatureadaptorUpdate(EnsPQcdasfeatureadaptor qcdasfa,
                                     const EnsPQcdasfeature qcdasf);
 
 AjBool ensQcdasfeatureadaptorDelete(EnsPQcdasfeatureadaptor qcdasfa,
-                                    const EnsPQcdasfeature qcdasf);
+                                    EnsPQcdasfeature qcdasf);
 
 /* Ensembl Quality Check Variation */
 
@@ -468,9 +498,9 @@ EnsPQcvariation ensQcvariationNew(EnsPQcvariationadaptor adaptor,
                                   ajuint tstart,
                                   ajuint tend,
                                   AjPStr tstring,
-                                  AjEnum class,
-                                  AjEnum type,
-                                  AjEnum state);
+                                  EnsEQcvariationClass class,
+                                  EnsEQcvariationType type,
+                                  EnsEQcvariationState state);
 
 EnsPQcvariation ensQcvariationNewObj(const EnsPQcvariation object);
 
@@ -502,74 +532,92 @@ ajuint ensQcvariationGetTargetEnd(const EnsPQcvariation qcv);
 
 AjPStr ensQcvariationGetTargetString(const EnsPQcvariation qcv);
 
-AjEnum ensQcvariationGetClass(const EnsPQcvariation qcv);
+EnsEQcvariationClass ensQcvariationGetClass(const EnsPQcvariation qcv);
 
-AjEnum ensQcvariationGetType(const EnsPQcvariation qcv);
+EnsEQcvariationType ensQcvariationGetType(const EnsPQcvariation qcv);
 
-AjEnum ensQcvariationGetState(const EnsPQcvariation qcv);
+EnsEQcvariationState ensQcvariationGetState(const EnsPQcvariation qcv);
 
 AjBool ensQcvariationSetAdaptor(EnsPQcvariation qcv,
                                 EnsPQcvariationadaptor qcva);
 
-AjBool ensQcvariationSetIdentifier(EnsPQcvariation qcv, ajuint identifier);
+AjBool ensQcvariationSetIdentifier(EnsPQcvariation qcv,
+                                   ajuint identifier);
 
-AjBool ensQcvariationSetQcalignment(EnsPQcvariation qcv, EnsPQcalignment qca);
+AjBool ensQcvariationSetQcalignment(EnsPQcvariation qcv,
+                                    EnsPQcalignment qca);
 
-AjBool ensQcvariationSetAnalysis(EnsPQcvariation qcv, EnsPAnalysis analysis);
+AjBool ensQcvariationSetAnalysis(EnsPQcvariation qcv,
+                                 EnsPAnalysis analysis);
 
 AjBool ensQcvariationSetQuerySequence(EnsPQcvariation qcv,
                                       EnsPQcsequence qsequence);
 
-AjBool ensQcvariationSetQueryStart(EnsPQcvariation qcv, ajuint qstart);
+AjBool ensQcvariationSetQueryStart(EnsPQcvariation qcv,
+                                   ajuint qstart);
 
-AjBool ensQcvariationSetQueryEnd(EnsPQcvariation qcv, ajuint qend);
+AjBool ensQcvariationSetQueryEnd(EnsPQcvariation qcv,
+                                 ajuint qend);
 
-AjBool ensQcvariationSetQueryString(EnsPQcvariation qcv, AjPStr qstring);
+AjBool ensQcvariationSetQueryString(EnsPQcvariation qcv,
+                                    AjPStr qstring);
 
 AjBool ensQcvariationSetTargetSequence(EnsPQcvariation qcv,
                                        EnsPQcsequence tsequence);
 
-AjBool ensQcvariationSetTargetStart(EnsPQcvariation qcv, ajuint tstart);
+AjBool ensQcvariationSetTargetStart(EnsPQcvariation qcv,
+                                    ajuint tstart);
 
-AjBool ensQcvariationSetTargetEnd(EnsPQcvariation qcv, ajuint tend);
+AjBool ensQcvariationSetTargetEnd(EnsPQcvariation qcv,
+                                  ajuint tend);
 
-AjBool ensQcvariationSetTargetString(EnsPQcvariation qcv, AjPStr tstring);
+AjBool ensQcvariationSetTargetString(EnsPQcvariation qcv,
+                                     AjPStr tstring);
 
-AjBool ensQcvariationSetClass(EnsPQcvariation qcv, AjEnum class);
+AjBool ensQcvariationSetClass(EnsPQcvariation qcv,
+                              EnsEQcvariationClass class);
 
-AjBool ensQcvariationSetType(EnsPQcvariation qcv, AjEnum type);
+AjBool ensQcvariationSetType(EnsPQcvariation qcv,
+                             EnsEQcvariationType type);
 
-AjBool ensQcvariationSetState(EnsPQcvariation qcv, AjEnum state);
+AjBool ensQcvariationSetState(EnsPQcvariation qcv,
+                              EnsEQcvariationState state);
 
-ajuint ensQcvariationGetMemSize(const EnsPQcvariation qcv);
+ajulong ensQcvariationGetMemsize(const EnsPQcvariation qcv);
 
 AjBool ensQcvariationTrace(const EnsPQcvariation qcv, ajuint level);
 
-AjEnum ensQcvariationClassFromStr(const AjPStr vclass);
+EnsEQcvariationClass ensQcvariationClassFromStr(const AjPStr vclass);
 
-AjEnum ensQcvariationTypeFromStr(const AjPStr type);
+EnsEQcvariationType ensQcvariationTypeFromStr(const AjPStr type);
 
-AjEnum ensQcvariationStateFromStr(const AjPStr state);
+EnsEQcvariationState ensQcvariationStateFromStr(const AjPStr state);
 
-const char *ensQcvariationClassToChar(const AjEnum vclass);
+const char *ensQcvariationClassToChar(EnsEQcvariationClass vclass);
 
-const char *ensQcvariationTypeToChar(const AjEnum type);
+const char *ensQcvariationTypeToChar(EnsEQcvariationType type);
 
-const char *ensQcvariationStateToChar(const AjEnum state);
+const char *ensQcvariationStateToChar(EnsEQcvariationState state);
 
 /* Ensembl Quality Check Variation Adaptor */
 
-EnsPQcvariationadaptor ensQcvariationadaptorNew(EnsPDatabaseadaptor dba);
+EnsPQcvariationadaptor ensRegistryGetQcvariationadaptor(
+    EnsPDatabaseadaptor dba);
+
+EnsPQcvariationadaptor ensQcvariationadaptorNew(
+    EnsPDatabaseadaptor dba);
 
 void ensQcvariationadaptorDel(EnsPQcvariationadaptor* Pqcva);
 
-AjBool ensQcvariationadaptorFetchByIdentifier(EnsPQcvariationadaptor adaptor,
-                                              ajuint identifier,
-                                              EnsPQcvariation *Pqcvf);
+AjBool ensQcvariationadaptorFetchByIdentifier(
+    EnsPQcvariationadaptor adaptor,
+    ajuint identifier,
+    EnsPQcvariation *Pqcvf);
 
-AjBool ensQcvariationadaptorFetchAllByQcalignment(EnsPQcvariationadaptor qcva,
-                                                  const EnsPQcalignment qca,
-                                                  AjPList qcvs);
+AjBool ensQcvariationadaptorFetchAllByQcalignment(
+    EnsPQcvariationadaptor qcva,
+    const EnsPQcalignment qca,
+    AjPList qcvs);
 
 AjBool ensQcvariationadaptorFetchAllByAnalysisQueryTarget(
     EnsPQcvariationadaptor qcva,
@@ -578,15 +626,17 @@ AjBool ensQcvariationadaptorFetchAllByAnalysisQueryTarget(
     const EnsPQcdatabase tdb,
     AjPList qcvs);
 
-AjBool ensQcvariationadaptorFetchAllByQuery(EnsPQcvariationadaptor qcva,
-                                            const EnsPAnalysis analysis,
-                                            const EnsPQcdatabase qdb,
-                                            AjPList qcvs);
+AjBool ensQcvariationadaptorFetchAllByQuery(
+    EnsPQcvariationadaptor qcva,
+    const EnsPAnalysis analysis,
+    const EnsPQcdatabase qdb,
+    AjPList qcvs);
 
-AjBool ensQcvariationadaptorFetchAllByTarget(EnsPQcvariationadaptor qcva,
-                                             const EnsPAnalysis analysis,
-                                             const EnsPQcdatabase tdb,
-                                             AjPList qcvs);
+AjBool ensQcvariationadaptorFetchAllByTarget(
+    EnsPQcvariationadaptor qcva,
+    const EnsPAnalysis analysis,
+    const EnsPQcdatabase tdb,
+    AjPList qcvs);
 
 AjBool ensQcvariationadaptorStore(EnsPQcvariationadaptor qcva,
                                   EnsPQcvariation qcv);
@@ -595,7 +645,7 @@ AjBool ensQcvariationadaptorUpdate(EnsPQcvariationadaptor qcva,
                                    const EnsPQcvariation qcv);
 
 AjBool ensQcvariationadaptorDelete(EnsPQcvariationadaptor qcva,
-                                   const EnsPQcvariation qcv);
+                                   EnsPQcvariation qcv);
 
 /* Ensembl Quality Check Submission */
 
@@ -611,111 +661,127 @@ EnsPQcsubmission ensQcsubmissionNew(EnsPQcsubmissionadaptor adaptor,
 
 EnsPQcsubmission ensQcsubmissionNewObj(const EnsPQcsubmission object);
 
-EnsPQcsubmission ensQcsubmissionNewRef(EnsPQcsubmission qcs);
+EnsPQcsubmission ensQcsubmissionNewRef(EnsPQcsubmission qcsb);
 
-void ensQcsubmissionDel(EnsPQcsubmission* Pqcs);
+void ensQcsubmissionDel(EnsPQcsubmission* Pqcsb);
 
-EnsPQcsubmissionadaptor ensQcsubmissionGetAdaptor(const EnsPQcsubmission qcs);
+EnsPQcsubmissionadaptor ensQcsubmissionGetAdaptor(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetIdentifier(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetIdentifier(const EnsPQcsubmission qcsb);
 
-EnsPAnalysis ensQcsubmissionGetAnalysis(const EnsPQcsubmission qcs);
+EnsPAnalysis ensQcsubmissionGetAnalysis(const EnsPQcsubmission qcsb);
 
-EnsPQcsequence ensQcsubmissionGetQuerySequence(const EnsPQcsubmission qcs);
+EnsPQcsequence ensQcsubmissionGetQuerySequence(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetQueryStart(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetQueryStart(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetQueryEnd(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetQueryEnd(const EnsPQcsubmission qcsb);
 
-ajint ensQcsubmissionGetQueryStrand(const EnsPQcsubmission qcs);
+ajint ensQcsubmissionGetQueryStrand(const EnsPQcsubmission qcsb);
 
-EnsPQcsequence ensQcsubmissionGetTargetSequence(const EnsPQcsubmission qcs);
+EnsPQcsequence ensQcsubmissionGetTargetSequence(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetTargetStart(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetTargetStart(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetTargetEnd(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetTargetEnd(const EnsPQcsubmission qcsb);
 
-ajint ensQcsubmissionGetTargetStrand(const EnsPQcsubmission qcs);
+ajint ensQcsubmissionGetTargetStrand(const EnsPQcsubmission qcsb);
 
-ajuint ensQcsubmissionGetAnalysisJobIdentifier(const EnsPQcsubmission qcs);
+ajuint ensQcsubmissionGetAnalysisJobIdentifier(const EnsPQcsubmission qcsb);
 
-AjBool ensQcsubmissionSetAdaptor(EnsPQcsubmission qcs,
-                                 EnsPQcsubmissionadaptor qcsa);
+AjBool ensQcsubmissionSetAdaptor(EnsPQcsubmission qcsb,
+                                 EnsPQcsubmissionadaptor qcsba);
 
-AjBool ensQcsubmissionSetIdentifier(EnsPQcsubmission qcs, ajuint identifier);
+AjBool ensQcsubmissionSetIdentifier(EnsPQcsubmission qcsb,
+                                    ajuint identifier);
 
-AjBool ensQcsubmissionSetAnalysis(EnsPQcsubmission qcs, EnsPAnalysis analysis);
+AjBool ensQcsubmissionSetAnalysis(EnsPQcsubmission qcsb,
+                                  EnsPAnalysis analysis);
 
-AjBool ensQcsubmissionSetQuerySequence(EnsPQcsubmission qcs,
-                                       EnsPQcsequence qcseq);
+AjBool ensQcsubmissionSetQuerySequence(EnsPQcsubmission qcsb,
+                                       EnsPQcsequence qsequence);
 
-AjBool ensQcsubmissionSetQueryStart(EnsPQcsubmission qcs, ajuint qstart);
+AjBool ensQcsubmissionSetQueryStart(EnsPQcsubmission qcsb,
+                                    ajuint qstart);
 
-AjBool ensQcsubmissionSetQueryEnd(EnsPQcsubmission qcs, ajuint qend);
+AjBool ensQcsubmissionSetQueryEnd(EnsPQcsubmission qcsb,
+                                  ajuint qend);
 
-AjBool ensQcsubmissionSetQueryStrand(EnsPQcsubmission qcs, ajint qstrand);
+AjBool ensQcsubmissionSetQueryStrand(EnsPQcsubmission qcsb,
+                                     ajint qstrand);
 
-AjBool ensQcsubmissionSetTargetSequence(EnsPQcsubmission qcs,
-                                        EnsPQcsequence qcseq);
+AjBool ensQcsubmissionSetTargetSequence(EnsPQcsubmission qcsb,
+                                        EnsPQcsequence tsequence);
 
-AjBool ensQcsubmissionSetTargetStart(EnsPQcsubmission qcs, ajuint tstart);
+AjBool ensQcsubmissionSetTargetStart(EnsPQcsubmission qcsb,
+                                     ajuint tstart);
 
-AjBool ensQcsubmissionSetTargetEnd(EnsPQcsubmission qcs, ajuint tend);
+AjBool ensQcsubmissionSetTargetEnd(EnsPQcsubmission qcsb,
+                                   ajuint tend);
 
-AjBool ensQcsubmissionSetTargetStrand(EnsPQcsubmission qcs, ajint tstrand);
+AjBool ensQcsubmissionSetTargetStrand(EnsPQcsubmission qcsb,
+                                      ajint tstrand);
 
-AjBool ensQcsubmissionSetAnalysisJobIdentifier(EnsPQcsubmission qcs,
+AjBool ensQcsubmissionSetAnalysisJobIdentifier(EnsPQcsubmission qcsb,
                                                ajuint jobid);
 
-ajuint ensQcsubmissionGetMemSize(const EnsPQcsubmission qcs);
+ajulong ensQcsubmissionGetMemsize(const EnsPQcsubmission qcsb);
 
-AjBool ensQcsubmissionTrace(const EnsPQcsubmission qcs, ajuint level);
+AjBool ensQcsubmissionTrace(const EnsPQcsubmission qcsb, ajuint level);
 
 /* Ensembl Quality Check Submission Adaptor */
 
-EnsPQcsubmissionadaptor ensQcsubmissionadaptorNew(EnsPDatabaseadaptor dba);
+EnsPQcsubmissionadaptor ensRegistryGetQcsubmissionadaptor(
+    EnsPDatabaseadaptor dba);
 
-void ensQcsubmissionadaptorDel(EnsPQcsubmissionadaptor* Pqcsa);
+EnsPQcsubmissionadaptor ensQcsubmissionadaptorNew(
+    EnsPDatabaseadaptor dba);
 
-AjBool ensQcsubmissionadaptorFetchByIdentifier(EnsPQcsubmissionadaptor adaptor,
-                                               ajuint identifier,
-                                               EnsPQcsubmission *Pqcs);
+void ensQcsubmissionadaptorDel(EnsPQcsubmissionadaptor* Pqcsba);
+
+AjBool ensQcsubmissionadaptorFetchByIdentifier(
+    EnsPQcsubmissionadaptor adaptor,
+    ajuint identifier,
+    EnsPQcsubmission *Pqcsb);
 
 AjBool ensQcsubmissionadaptorFetchAllByAnalysisQueryTarget(
-    EnsPQcsubmissionadaptor qcsa,
+    EnsPQcsubmissionadaptor qcsba,
     const EnsPAnalysis analysis,
     const EnsPQcdatabase qdb,
     const EnsPQcdatabase tdb,
-    AjPList qcss);
+    AjPList qcsbs);
 
-AjBool ensQcsubmissionadaptorFetchAllByANQIDTDB(EnsPQcsubmissionadaptor qcsa,
-                                                const EnsPAnalysis analysis,
-                                                const EnsPQcsequence qseqeunce,
-                                                const EnsPQcdatabase tdb,
-                                                const EnsPQcsequence tsequence,
-                                                ajuint tstart,
-                                                ajuint tend,
-                                                ajint tstrand,
-                                                AjPList qcss);
+AjBool ensQcsubmissionadaptorFetchAllByANQIDTDB(
+    EnsPQcsubmissionadaptor qcsba,
+    const EnsPAnalysis analysis,
+    const EnsPQcsequence qseqeunce,
+    const EnsPQcdatabase tdb,
+    const EnsPQcsequence tsequence,
+    ajuint tstart,
+    ajuint tend,
+    ajint tstrand,
+    AjPList qcsbs);
 
-AjBool ensQcsubmissionadaptorFetchAllByQuery(EnsPQcsubmissionadaptor qcsa,
-                                             const EnsPAnalysis analysis,
-                                             const EnsPQcdatabase qdb,
-                                             AjPList qcss);
+AjBool ensQcsubmissionadaptorFetchAllByQuery(
+    EnsPQcsubmissionadaptor qcsba,
+    const EnsPAnalysis analysis,
+    const EnsPQcdatabase qdb,
+    AjPList qcsbs);
 
-AjBool ensQcsubmissionadaptorFetchAllByTarget(EnsPQcsubmissionadaptor qcsa,
-                                              const EnsPAnalysis analysis,
-                                              const EnsPQcdatabase tdb,
-                                              AjPList qcss);
+AjBool ensQcsubmissionadaptorFetchAllByTarget(
+    EnsPQcsubmissionadaptor qcsba,
+    const EnsPAnalysis analysis,
+    const EnsPQcdatabase tdb,
+    AjPList qcsbs);
 
-AjBool ensQcsubmissionadaptorStore(EnsPQcsubmissionadaptor qcsa,
-                                   EnsPQcsubmission qcs);
+AjBool ensQcsubmissionadaptorStore(EnsPQcsubmissionadaptor qcsba,
+                                   EnsPQcsubmission qcsb);
 
-AjBool ensQcsubmissionadaptorUpdate(EnsPQcsubmissionadaptor qcsa,
-                                    const EnsPQcsubmission qcs);
+AjBool ensQcsubmissionadaptorUpdate(EnsPQcsubmissionadaptor qcsba,
+                                    const EnsPQcsubmission qcsb);
 
-AjBool ensQcsubmissionadaptorDelete(EnsPQcsubmissionadaptor qcsa,
-                                    const EnsPQcsubmission qcs);
+AjBool ensQcsubmissionadaptorDelete(EnsPQcsubmissionadaptor qcsba,
+                                    EnsPQcsubmission qcsb);
 
 /*
 ** End of prototype definitions
@@ -724,7 +790,7 @@ AjBool ensQcsubmissionadaptorDelete(EnsPQcsubmissionadaptor qcsa,
 
 
 
-#endif
+#endif /* ensqc_h */
 
 #ifdef __cplusplus
 }
