@@ -13,12 +13,13 @@ extern "C"
 
 
 
-/* @data EnsPGvalleleadaptor **************************************************
+/* #data EnsPGvalleleadaptor **************************************************
 **
 ** Ensembl Genetic Variation Allele Adaptor.
+** Defined as an alias in EnsPDatabaseadaptor
 **
-** @alias EnsPDatabaseadaptor
-** @@
+** #alias EnsPDatabaseadaptor
+** ##
 ** NOTE: Although the Bio::EnsEMBL::Variation::Allele object is based on the
 ** Bio::EnsEMBL::Storable object, there is actually no
 ** Bio::EnsEMBL::Variation::DBSQL::AlleleAdaptor as such in the
@@ -66,12 +67,13 @@ typedef struct EnsSGvallele
 
 
 
-/* @data EnsPGvgenotypeadaptor ************************************************
+/* #data EnsPGvgenotypeadaptor ************************************************
 **
 ** Ensembl Genetic Variation Genotype Adaptor.
+** Defined as an alias in EnsPDatabaseadaptor
 **
-** @alias EnsPDatabaseadaptor
-** @@
+** #alias EnsPDatabaseadaptor
+** ##
 ******************************************************************************/
 
 #define EnsPGvgenotypeadaptor EnsPDatabaseadaptor
@@ -111,12 +113,73 @@ typedef struct EnsSGvgenotype
 
 
 
-/* @data EnsPGvvariationadaptor ***********************************************
+/* @data EnsPGvsourceadaptor **************************************************
+**
+** Ensembl Genetic Variation Source Adaptor.
+**
+** @alias EnsSGvsourceadaptor
+** @alias EnsOGvsourceadaptor
+**
+** @attr Adaptor [EnsPBaseadaptor] Ensembl Base Adaptor
+** @attr CacheByIdentifier [AjPTable] Identifier cache
+** @attr CacheByName [AjPTable] Name cache
+** @@
+******************************************************************************/
+
+typedef struct EnsSGvsourceadaptor {
+    EnsPBaseadaptor Adaptor;
+    AjPTable CacheByIdentifier;
+    AjPTable CacheByName;
+} EnsOGvsourceadaptor;
+
+#define EnsPGvsourceadaptor EnsOGvsourceadaptor*
+
+
+
+
+/* @data EnsPGvsource *********************************************************
+**
+** Ensembl Genetic Variation Source.
+**
+** @alias EnsSGvsource
+** @alias EnsOGvsource
+**
+** @attr Use [ajuint] Use counter
+** @cc Bio::EnsEMBL::Storable
+** @attr Identifier [ajuint] SQL database-internal identifier
+** @attr Adaptor [EnsPGvsourceadaptor] Ensembl Genetic Variation
+**                                     Source Adaptor
+** @cc Bio::EnsEMBL::Variation::??
+** @attr Name [AjPStr] Name
+** @attr Version [AjPStr] Version
+** @attr Description [AjPStr] Description
+** @attr URL [AjPStr] Uniform Resource Locator
+** @@
+******************************************************************************/
+
+typedef struct EnsSGvsource
+{
+    ajuint Use;
+    ajuint Identifier;
+    EnsPGvsourceadaptor Adaptor;
+    AjPStr Name;
+    AjPStr Version;
+    AjPStr Description;
+    AjPStr URL;
+} EnsOGvsource;
+
+#define EnsPGvsource EnsOGvsource*
+
+
+
+
+/* #data EnsPGvvariationadaptor ***********************************************
 **
 ** Ensembl Genetic Variation Variation Adaptor.
+** Defined as an alias in EnsPDatabaseadaptor
 **
-** @alias EnsPDatabaseadaptor
-** @@
+** #alias EnsPDatabaseadaptor
+** ##
 ******************************************************************************/
 
 #define EnsPGvvariationadaptor EnsPDatabaseadaptor
@@ -130,7 +193,7 @@ typedef struct EnsSGvgenotype
 **
 ******************************************************************************/
 
-enum EnsEGvvariationValidationState
+typedef enum EnsOGvvariationValidationState
 {
     ensEGvvariationValidationStateNULL,
     ensEGvvariationValidationStateCluster,
@@ -142,7 +205,7 @@ enum EnsEGvvariationValidationState
     ensEGvvariationValidationStateNonPolymorphic,
     ensEGvvariationValidationStateObserved,
     ensEGvvariationValidationStateUnknown
-};
+} EnsEGvvariationValidationState;
 
 
 
@@ -160,18 +223,18 @@ enum EnsEGvvariationValidationState
 ** @attr Adaptor [EnsPGvvariationadaptor] Ensembl Genetic Variation
 **                                        Variation Adaptor
 ** @cc Bio::EnsEMBL::Variation::Variation
+** @attr Gvsource [EnsPGvsource] Ensembl Genetic Variation Source
 ** @attr Name [AjPStr] Name
-** @attr Source [AjPStr] Source
 ** @attr Synonyms [AjPTable] Synonyms
 ** @attr Handles [AjPTable] Handles
 ** @attr AncestralAllele [AjPStr] Ancestral allele
 ** @attr Gvalleles [AjPList] AJAX List of Ensembl Genetic Variation Alleles
-** @attr ValidationStates [AjPList] AJAX List of AJAX Strings of validation
-**                                  states
 ** @attr MoleculeType [AjPStr] Molecule type
 ** @attr FivePrimeFlank [AjPStr] Five prime flanking sequence
 ** @attr ThreePrimeFlank [AjPStr] Three prime flanking sequence
 ** @attr FailedDescription [AjPStr] Failed description
+** @attr ValidationStates [ajuint] Bit field of validation states
+** @attr Padding [ajuint] Padding to alignment boundary
 ** @@
 ******************************************************************************/
 
@@ -180,17 +243,18 @@ typedef struct EnsSGvvariation
     ajuint Use;
     ajuint Identifier;
     EnsPGvvariationadaptor Adaptor;
+    EnsPGvsource Gvsource;
     AjPStr Name;
-    AjPStr Source;
     AjPTable Synonyms;
     AjPTable Handles;
     AjPStr AncestralAllele;
     AjPList Gvalleles;
-    AjPList ValidationStates;
     AjPStr MoleculeType;
     AjPStr FivePrimeFlank;
     AjPStr ThreePrimeFlank;
     AjPStr FailedDescription;
+    ajuint ValidationStates;
+    ajuint Padding;
 } EnsOGvvariation;
 
 #define EnsPGvvariation EnsOGvvariation*
@@ -311,10 +375,15 @@ AjBool ensGvalleleSetFrequency(EnsPGvallele gva, float frequency);
 
 AjBool ensGvalleleSetSubSNPIdentifier(EnsPGvallele gva, ajuint subsnpid);
 
-ajuint ensGvalleleGetMemSize(const EnsPGvallele gva);
+ajulong ensGvalleleGetMemsize(const EnsPGvallele gva);
 
 AjBool ensGvalleleTrace(const EnsPGvallele gva, ajuint level);
 
+/* Ensembl Genetic Variation Allele Adaptor */
+
+EnsPGvalleleadaptor ensRegistryGetGvalleleadaptor(
+    EnsPDatabaseadaptor dba);
+
 /* Ensembl Genetic Variation Genotype */
 
 EnsPGvgenotype ensGvgenotypeNew(EnsPGvgenotypeadaptor gvga,
@@ -344,20 +413,94 @@ AjBool ensGvgenotypeSetAllele1(EnsPGvgenotype gvg, AjPStr allele1);
 
 AjBool ensGvgenotypeSetAllele2(EnsPGvgenotype gvg, AjPStr allele2);
 
-ajuint ensGvgenotypeGetMemSize(const EnsPGvgenotype gvg);
+ajulong ensGvgenotypeGetMemsize(const EnsPGvgenotype gvg);
 
 AjBool ensGvgenotypeTrace(const EnsPGvgenotype gvg, ajuint level);
 
+/* Ensembl Genetic Variation Genotype Adaptor */
+
+EnsPGvgenotypeadaptor ensRegistryGetGvgenotypeadaptor(
+    EnsPDatabaseadaptor dba);
+
+/* Ensembl Genetic Variation Source */
+
+EnsPGvsource ensGvsourceNew(EnsPGvsourceadaptor gvsa,
+                            ajuint identifier,
+                            AjPStr name,
+                            AjPStr version,
+                            AjPStr description,
+                            AjPStr url);
+
+EnsPGvsource ensGvsourceNewObj(const EnsPGvsource object);
+
+EnsPGvsource ensGvsourceNewRef(EnsPGvsource gvs);
+
+void ensGvsourceDel(EnsPGvsource *Pgvs);
+
+EnsPGvsourceadaptor ensGvsourceGetAdaptor(const EnsPGvsource gvs);
+
+ajuint ensGvsourceGetIdentifier(const EnsPGvsource gvs);
+
+AjPStr ensGvsourceGetName(const EnsPGvsource gvs);
+
+AjPStr ensGvsourceGetVersion(const EnsPGvsource gvs);
+
+AjPStr ensGvsourceGetDescription(const EnsPGvsource gvs);
+
+AjPStr ensGvsourceGetURL(const EnsPGvsource gvs);
+
+AjBool ensGvsourceSetAdaptor(EnsPGvsource gvs, EnsPGvsourceadaptor gvsa);
+
+AjBool ensGvsourceSetIdentifier(EnsPGvsource gvs, ajuint identifier);
+
+AjBool ensGvsourceSetName(EnsPGvsource gvs, AjPStr name);
+
+AjBool ensGvsourceSetVersion(EnsPGvsource gvs, AjPStr version);
+
+AjBool ensGvsourceSetDescription(EnsPGvsource gvs, AjPStr description);
+
+AjBool ensGvsourceSetURL(EnsPGvsource gvs, AjPStr url);
+
+ajulong ensGvsourceGetMemsize(const EnsPGvsource gvs);
+
+AjBool ensGvsourceTrace(const EnsPGvsource gvs, ajuint level);
+
+/* Ensembl Genetic Variation Source Adaptor */
+
+EnsPGvsourceadaptor ensRegistryGetGvsourceadaptor(
+    EnsPDatabaseadaptor dba);
+
+EnsPGvsourceadaptor ensGvsourceadaptorNew(EnsPDatabaseadaptor dba);
+
+void ensGvsourceadaptorDel(EnsPGvsourceadaptor* Pgvsa);
+
+EnsPBaseadaptor ensGvsourceadaptorGetBaseadaptor(
+    const EnsPGvsourceadaptor gvsa);
+
+EnsPDatabaseadaptor ensGvsourceadaptorGetDatabaseadaptor(
+    const EnsPGvsourceadaptor gvsa);
+
+AjBool ensGvsourceadaptorFetchAll(EnsPGvsourceadaptor gvsa,
+                                  AjPList gvss);
+
+AjBool ensGvsourceadaptorFetchByIdentifier(EnsPGvsourceadaptor gvsa,
+                                           ajuint identifier,
+                                           EnsPGvsource *Pgvs);
+
+AjBool ensGvsourceadaptorFetchByName(EnsPGvsourceadaptor gvsa,
+                                     const AjPStr name,
+                                     EnsPGvsource *Pgvs);
+
 /* Ensembl Genetic Variation Variation */
 
-EnsPGvvariation ensGvvariationNew(EnsPGvvariationadaptor adaptor,
+EnsPGvvariation ensGvvariationNew(EnsPGvvariationadaptor gvva,
                                   ajuint identifier,
+                                  EnsPGvsource gvs,
                                   AjPStr name,
-                                  AjPStr source,
                                   AjPStr ancestralallele,
                                   AjPTable synonyms,
                                   AjPList alleles,
-                                  AjPList validationstates,
+                                  AjPStr validationstates,
                                   AjPStr moltype,
                                   AjPStr fiveflank,
                                   AjPStr threeflank,
@@ -373,9 +516,9 @@ EnsPGvvariationadaptor ensGvvariationGetAdaptor(const EnsPGvvariation gvv);
 
 ajuint ensGvvariationGetIdentifier(const EnsPGvvariation gvv);
 
-AjPStr ensGvvariationGetName(const EnsPGvvariation gvv);
+EnsPGvsource ensGvvariationGetGvsource(const EnsPGvvariation gvv);
 
-AjPStr ensGvvariationGetSource(const EnsPGvvariation gvv);
+AjPStr ensGvvariationGetName(const EnsPGvvariation gvv);
 
 const AjPTable ensGvvariationGetSynonyms(const EnsPGvvariation gvv);
 
@@ -383,7 +526,7 @@ AjPStr ensGvvariationGetAncestralAllele(const EnsPGvvariation gvv);
 
 const AjPList ensGvvariationGetGvalleles(const EnsPGvvariation gvv);
 
-const AjPList ensGvvariationGetValidationStates(const EnsPGvvariation gvv);
+ajuint ensGvvariationGetValidationStates(const EnsPGvvariation gvv);
 
 AjPStr ensGvvariationGetMoleculeType(const EnsPGvvariation gvv);
 
@@ -396,13 +539,17 @@ AjPStr ensGvvariationGetFailedDescription(const EnsPGvvariation gvv);
 AjBool ensGvvariationSetAdaptor(EnsPGvvariation gvv,
                                 EnsPGvvariationadaptor gvva);
 
-AjBool ensGvvariationSetIdentifier(EnsPGvvariation gvv, ajuint identifier);
+AjBool ensGvvariationSetIdentifier(EnsPGvvariation gvv,
+                                   ajuint identifier);
 
-AjBool ensGvvariationSetName(EnsPGvvariation gvv, AjPStr name);
+AjBool ensGvvariationSetGvsource(EnsPGvvariation gvv,
+                                 EnsPGvsource gvs);
 
-AjBool ensGvvariationSetSource(EnsPGvvariation gvv, AjPStr source);
+AjBool ensGvvariationSetName(EnsPGvvariation gvv,
+                             AjPStr name);
 
-AjBool ensGvvariationSetMoleculeType(EnsPGvvariation gvv, AjPStr moltype);
+AjBool ensGvvariationSetMoleculeType(EnsPGvvariation gvv,
+                                     AjPStr moltype);
 
 AjBool ensGvvariationSetAncestralAllele(EnsPGvvariation gvv,
                                         AjPStr ancestralallele);
@@ -416,7 +563,7 @@ AjBool ensGvvariationSetThreePrimeFlank(EnsPGvvariation gvv,
 AjBool ensGvvariationSetFailedDescription(EnsPGvvariation gvv,
                                           AjPStr faileddescription);
 
-ajuint ensGvvariationGetMemSize(const EnsPGvvariation gvv);
+ajulong ensGvvariationGetMemsize(const EnsPGvvariation gvv);
 
 AjBool ensGvvariationTrace(const EnsPGvvariation gvv, ajuint level);
 
@@ -427,9 +574,18 @@ AjBool ensGvvariationAddSynonym(EnsPGvvariation gvv,
 
 AjBool ensGvvariationAddGvallele(EnsPGvvariation gvv, EnsPGvallele gva);
 
-AjEnum ensGvvariationValidationStateFromStr(const AjPStr state);
+AjBool ensGvvariationAddValidationState(EnsPGvvariation gvv,
+                                        EnsEGvvariationValidationState state);
 
-const char *ensGvvariationValidationStateToChar(const AjEnum state);
+EnsEGvvariationValidationState ensGvvariationValidationStateFromStr(
+    const AjPStr state);
+
+const char *ensGvvariationValidationStateToChar(
+    EnsEGvvariationValidationState state);
+
+ajuint ensGvvariationValidationStatesFromSet(const AjPStr set);
+
+AjBool ensGvvariationValidationStatesToSet(ajuint states, AjPStr *Pstr);
 
 AjBool ensGvvariationFetchAllSynonyms(const EnsPGvvariation gvv,
                                       const AjPStr source,
@@ -444,6 +600,9 @@ AjBool ensGvvariationFetchHandleBySynonym(EnsPGvvariation gvv,
 
 /* Ensembl Genetic Variation Variation Adaptor */
 
+EnsPGvvariationadaptor ensRegistryGetGvvariationadaptor(
+    EnsPDatabaseadaptor dba);
+
 AjBool ensGvvariationadaptorFetchByIdentifier(EnsPGvvariationadaptor gvva,
                                               ajuint identifier,
                                               EnsPGvvariation *Pgvv);
@@ -458,7 +617,7 @@ AjBool ensGvvariationadaptorFetchAllBySource(EnsPGvvariationadaptor gvva,
                                              AjBool primary,
                                              AjPList gvvs);
 
-AjBool ensGvvariationAdaptorFetchAllByGvpopulation(EnsPGvvariationadaptor gvva,
+AjBool ensGvvariationadaptorFetchAllByGvpopulation(EnsPGvvariationadaptor gvva,
                                                    const EnsPGvpopulation gvp,
                                                    AjPList gvvs);
 
@@ -545,11 +704,15 @@ AjBool ensGvvariationfeatureSetConsequenceType(EnsPGvvariationfeature gvvf,
 AjBool ensGvvariationfeatureSetMapWeight(EnsPGvvariationfeature gvvf,
                                          ajuint mapweight);
 
-ajuint ensGvvariationfeatureGetMemSize(const EnsPGvvariationfeature gvvf);
+ajulong ensGvvariationfeatureGetMemsize(const EnsPGvvariationfeature gvvf);
 
 AjBool ensGvvariationfeatureTrace(const EnsPGvvariationfeature gvvf,
                                   ajuint level);
 
+AjBool ensGvvariationfeatureSortByStartAscending(AjPList gvvfs);
+
+AjBool ensGvvariationfeatureSortByStartDescending(AjPList gvvfs);
+
 /*
 ** End of prototype definitions
 */
@@ -557,7 +720,7 @@ AjBool ensGvvariationfeatureTrace(const EnsPGvvariationfeature gvvf,
 
 
 
-#endif
+#endif /* ensvariation_h */
 
 #ifdef __cplusplus
 }
