@@ -25,25 +25,25 @@
 
 
 
-/* @datastatic AjPIntarr ******************************************************
+/* @datastatic PIntarr ******************************************************
 **
 ** Integer array
 **
-** @alias AjSIntarr
-** @alias AjPIntarr
+** @alias SIntarr
+** @alias PIntarr
 **
 ** @attr Array [ajint*] Integer array
 ** @attr Size [ajint] Size
 ** @attr Padding [char[4]] Padding to alignment boundary
 ******************************************************************************/
 
-typedef struct AjSIntarr
+typedef struct SIntarr
 {
     ajint* Array;
     ajint Size;
     char Padding[4];
-} AjOIntarr;
-#define AjPIntarr AjOIntarr*
+} OIntarr;
+#define PIntarr OIntarr*
 
 
 
@@ -217,7 +217,7 @@ int main(int argc, char **argv)
      /*
      ** plot is an XY graph definition object created by acdSetGraphxy
      ** something like this to plot the data:
-     ** sequence, startposition, increment, array, arraysize
+     ** sequence, start position, increment, array, array size
      ** Note: seq has Begin and End values which can limit the plot range
      **
      ** ioff = ibeg + iwin/2;
