@@ -74,7 +74,7 @@
 
 
 
-static AjBool jembossctl_up(const char *buf,int *uid,int *gid,AjPStr *home);
+static AjBool jembossctl_up(char *buf,int *uid,int *gid,AjPStr *home);
 static AjBool jembossctl_do_fork(char *buf, int uid, int gid);
 static AjBool jembossctl_do_batch(char *buf, int uid, int gid);
 static AjBool jembossctl_do_directory(char *buf, int uid, int gid);
@@ -97,7 +97,7 @@ static void jembossctl_tidy_strings(AjPStr *tstr, AjPStr *home,
 				    char *buf);
 static void jembossctl_fork_tidy(AjPStr *cl, AjPStr *prog, AjPStr *enviro,
 				 AjPStr *dir, AjPStr *outstd, AjPStr *errstd);
-static AjBool jembossctl_check_buffer(const char *buf, int mlen);
+static AjBool jembossctl_check_buffer(char *buf, int mlen);
 static AjBool jembossctl_chdir(const char *file);
 static AjBool jembossctl_initgroups(const char *buf, int gid);
 static void jembossctl_zero(char *buf);
@@ -187,7 +187,7 @@ extern char *strptime(const char *s, const char *format, struct tm *tm);
 **
 ******************************************************************************/
 
-int main(int argc, char **argv)
+int main(void)
 {
     AjPStr message = NULL;
     char *cbuf = NULL;
@@ -274,7 +274,7 @@ int main(int argc, char **argv)
     case COMM_AUTH:
 	ajStrAssignC(&tstr,cbuf);
 	c='\0';
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    c=1;
 
@@ -291,7 +291,7 @@ int main(int argc, char **argv)
 
     case EMBOSS_FORK:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 
 	if(ok)
 	    ok = jembossctl_do_fork(cbuf,uid,gid);
@@ -299,28 +299,28 @@ int main(int argc, char **argv)
 
     case MAKE_DIRECTORY:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_directory(cbuf,uid,gid);
 	break;
 
     case DELETE_FILE:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_deletefile(cbuf,uid,gid);
 	break;
 
     case DELETE_DIR:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_deletedir(cbuf,uid,gid);
 	break;
 
     case LIST_FILES:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 
 	if(ok)
 	    ok = jembossctl_do_listfiles(cbuf,uid,gid,&retlist);
@@ -330,7 +330,7 @@ int main(int argc, char **argv)
 
     case LIST_DIRS:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_listdirs(cbuf,uid,gid,&retlist);
 
@@ -339,7 +339,7 @@ int main(int argc, char **argv)
 
     case GET_FILE:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_getfile(cbuf,uid,gid,&fbuf,&size);
 
@@ -347,7 +347,7 @@ int main(int argc, char **argv)
 
     case PUT_FILE:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_putfile(cbuf,uid,gid);
 
@@ -355,7 +355,7 @@ int main(int argc, char **argv)
 
     case BATCH_FORK:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 
 	if(ok)
 	    ok = jembossctl_do_batch(cbuf,uid,gid);
@@ -363,7 +363,7 @@ int main(int argc, char **argv)
 
     case RENAME_FILE:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_renamefile(cbuf,uid,gid);
 	break;
@@ -371,14 +371,14 @@ int main(int argc, char **argv)
 
     case SEQ_ATTRIB:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_seq(cbuf,uid,gid);
 	break;
 
     case SEQSET_ATTRIB:
 	ajStrAssignC(&tstr,cbuf);
-	ok = jembossctl_up(ajStrGetPtr(tstr),&uid,&gid,&home);
+	ok = jembossctl_up(tstr->Ptr,&uid,&gid,&home);
 	if(ok)
 	    ok = jembossctl_do_seqset(cbuf,uid,gid);
 	break;
@@ -410,7 +410,7 @@ int main(int argc, char **argv)
 ** @@
 ******************************************************************************/
 
-static void jembossctl_empty_core_dump()
+static void jembossctl_empty_core_dump(void)
 {
     struct rlimit limit;
 
@@ -749,6 +749,8 @@ struct ad_user
 };
 
 
+
+
 /* @header jembossctl_pam_conv ************************************************
 **
 ******************************************************************************/
@@ -875,7 +877,7 @@ static AjBool jembossctl_check_pass(AjPStr username,AjPStr password,ajint *uid,
 **
 ** Primary username/password check. Return uid/gid/homedir
 **
-** @param [w] buf [const char*] socket buffer
+** @param [w] buf [char*] socket buffer
 ** @param [w] uid [int*] uid
 ** @param [w] gid [int*] gid
 ** @param [w] home [AjPStr*] home
@@ -883,7 +885,7 @@ static AjBool jembossctl_check_pass(AjPStr username,AjPStr password,ajint *uid,
 ** @return [AjBool] true if success
 ******************************************************************************/
 
-static AjBool jembossctl_up(const char *buf, int *uid, int *gid, AjPStr *home)
+static AjBool jembossctl_up(char *buf, int *uid, int *gid, AjPStr *home)
 {
     AjPStr username = NULL;
     AjPStr password = NULL;
@@ -900,9 +902,9 @@ static AjBool jembossctl_up(const char *buf, int *uid, int *gid, AjPStr *home)
     if(ajFmtScanS(cstr,"%d%S%S",&command,&username,&password)!=3)
     {
 	if(ajStrGetLen(username))
-	   bzero((void*)ajStrGetPtr(username),ajStrGetLen(username));
+	   bzero((void*)username->Ptr,ajStrGetLen(username));
 	if(ajStrGetLen(password))
-	   bzero((void*)ajStrGetPtr(password),ajStrGetLen(password));
+	   bzero((void*)password->Ptr,ajStrGetLen(password));
 	jembossctl_zero((char*)buf);
 
 	ajStrDel(&username);
@@ -924,11 +926,13 @@ static AjBool jembossctl_up(const char *buf, int *uid, int *gid, AjPStr *home)
 
 #ifndef NO_AUTH
     ok = jembossctl_check_pass(username,password,uid,gid,home);
+#else
+    (void) home;
 #endif
 
 
-    bzero((void*)ajStrGetPtr(username),ajStrGetLen(username));
-    bzero((void*)ajStrGetPtr(password),ajStrGetLen(password));
+    bzero((void*)username->Ptr,ajStrGetLen(username));
+    bzero((void*)password->Ptr,ajStrGetLen(password));
     jembossctl_zero((char*)buf);
 
     ajStrDel(&username);
@@ -1107,12 +1111,7 @@ static AjBool jembossctl_do_batch(char *buf, int uid, int gid)
 	    exit(-1);
 	}
 
-	if(execve(ajStrGetPtr(prog),argp,envp) == -1)
-	{
-	    fprintf(stderr,"execve failure");
-	    fflush(stderr);
-	    exit(-1);
-	}
+	ajSysExecProgArgEnvNowaitC(ajStrGetPtr(prog),argp,envp);
     }
 
 
@@ -1278,7 +1277,11 @@ static AjBool jembossctl_do_batch(char *buf, int uid, int gid)
 	return ajFalse;
     }
 
-
+/*
+    fprintf(stdout,"%s",ajStrGetPtr(outstd));
+    fprintf(stderr,"%s",ajStrGetPtr(errstd));
+*/
+    
     close(errpipe[0]);
     close(errpipe[1]);
     close(outpipe[0]);
@@ -1342,6 +1345,25 @@ static AjBool jembossctl_do_batch(char *buf, int uid, int gid)
 	return ajFalse;
     }
 
+    if(ajStrGetLen(errstd))
+    {
+        if(!(fp=fopen("stderrfile","w")))
+        {
+            fprintf(stderr,"errfile fopen error (do_batch)\n");
+            jembossctl_fork_tidy(&cl,&prog,&enviro,&dir,&outstd,&errstd);
+            return ajFalse;
+        }
+
+        fprintf(fp,"%s\n",ajStrGetPtr(errstd));
+    
+        if(fclose(fp))
+        {
+            fprintf(stderr,"errfile fclose error (do_batch)\n");
+            jembossctl_fork_tidy(&cl,&prog,&enviro,&dir,&outstd,&errstd);
+            return ajFalse;
+        }
+    }
+    
     jembossctl_fork_tidy(&cl,&prog,&enviro,&dir,&outstd,&errstd);
 
     return ajTrue;
@@ -1497,12 +1519,7 @@ static AjBool jembossctl_do_fork(char *buf, int uid, int gid)
 	    exit(-1);
 	}
 
-	if(execve(ajStrGetPtr(prog),argp,envp) == -1)
-	{
-	    fprintf(stderr,"execve failure");
-	    fflush(stderr);
-	    exit(-1);
-	}
+	ajSysExecProgArgEnvNowaitC(ajStrGetPtr(prog),argp,envp);
     }
 
 
@@ -1695,37 +1712,138 @@ static AjBool jembossctl_do_fork(char *buf, int uid, int gid)
 /* @funcstatic jembossctl_make_array ******************************************
 **
 ** Construct argv and env arrays for Ajax.fork
+** N.B. This function converts tabs to spaces and removes
+** excess space characters.
 **
-** @param [r] str [const AjPStr] space separated tokens
+** @param [r] str [const AjPStr] space or doublequote separated tokens
 **
 ** @return [char**] env or argv array
 ******************************************************************************/
 
 static char** jembossctl_make_array(const AjPStr str)
 {
-    int n;
-    char **ptr = NULL;
-    AjPStr buf;
-    const char *save = NULL;
+    ajint n = 0;
+    ajint len = 0;
+    
+    char **ptr    = NULL;
+    const char *p = NULL;
+    const char *q = NULL;
+    char c;
+    AjPStr stmp = NULL;
+    AjPStr buf  = NULL;
+    
 
-    buf = ajStrNew();
+    n = 0;
+
+    stmp = ajStrNewS(str);
+    
+    ajStrRemoveWhiteExcess(&stmp);
+
+    p = ajStrGetPtr(stmp);
+    q = p;
+    
+    /*
+    ** Count the number of tokens
+    */
+
+    while((c = *p))
+    {
+        if(c == '"')
+        {
+            ++p;
+            
+            while(*p != '"' && *p)
+                ++p;
+
+            if(*p)
+                ++p;
+
+            if(*p == ' ')
+            {
+                ++n;
+                ++p;
+            }
+            
+            continue;
+        }
+
+        if(c == ' ')
+            ++n;
+
+        ++p;
+    }
+
+    if(p != q)
+        ++n;
 
-    n = ajStrParseCountMultiC(str," \t\n");
 
     AJCNEW0(ptr,n+1);
 
     ptr[n] = NULL;
 
+    /* If there are no tokens return an empty NULL terminated list */
+    if(!n)
+    {
+        ajStrDel(&stmp);
+        return ptr;
+    }
+    
+
+    /*
+    ** Tokenise and create ptr array strings
+    */
+
+    buf = ajStrNew();
+
+    p = q;
     n = 0;
+    
+    while((c = *p))
+    {
+        
+        if(c == '"')
+        {
+            ++p;
+            while(*p != '"' && *p)
+                ++p;
 
-    if(!ajSysFuncStrtokR(ajStrGetPtr(str)," \t\n",&save,&buf))
-	return ptr;
-    ptr[n++] = ajCharNewS(buf);
+            len = p-q;
+            
+            
+            if(*p)
+                ++p;
 
-    while(ajSysFuncStrtokR(NULL," \t\n",&save,&buf))
-	ptr[n++] = ajCharNewS(buf);
+            if(len > 1)
+                ajStrAssignSubC(&buf,q,1,len-1);
+            else
+                ajStrAssignC(&buf,"");
 
+            ptr[n++] = ajCharNewS(buf);
+            
+            if(*p == ' ')
+                ++p;
+
+            q = p;
+            continue;
+        }
+        
+        while(*p != ' ' && *p)
+            ++p;
+
+        len = p-q;
+        
+        ajStrAssignSubC(&buf,q,0,len-1);
+        ptr[n++] = ajCharNewS(buf);
+        
+        if(*p == ' ')
+            ++p;
+
+        q = p;
+    }
+
+        
     ajStrDel(&buf);
+    ajStrDel(&stmp);
 
     return ptr;
 }
@@ -2222,13 +2340,8 @@ static AjBool jembossctl_do_deletedir(char *buf, int uid, int gid)
 	return ajFalse;
     }
 
-
-    cmnd = ajStrNew();
-    ajFmtPrintS(&cmnd,"rm -rf %S",dir);
-
-
-#ifndef __ppc__
-    if(system(ajStrGetPtr(cmnd))==-1)
+    ajSysCommandRemovedirS(dir);
+    if(!ajFilenameExists(dir))
     {
 	fprintf(stderr,"system error (delete directory)\n");
 	ajStrDel(&cmnd);
@@ -2236,9 +2349,6 @@ static AjBool jembossctl_do_deletedir(char *buf, int uid, int gid)
 	return ajFalse;
     }
 
-#else
-    ajSysSystem(cmnd);
-#endif
 
     ajStrDel(&cmnd);
     ajStrDel(&dir);
@@ -3243,13 +3353,13 @@ static void jembossctl_fork_tidy(AjPStr *cl, AjPStr *prog, AjPStr *enviro,
 **
 ** Sanity check on socket commands
 **
-** @param [r] buf [const char*] socket buffer
+** @param [u] buf [char*] socket buffer
 ** @param [r] mlen [int] buffer length
 **
 ** @return [AjBool] true if sane
 ******************************************************************************/
 
-static AjBool jembossctl_check_buffer(const char *buf, int mlen)
+static AjBool jembossctl_check_buffer(char *buf, int mlen)
 {
     const char *p;
     int str1len;
@@ -3822,7 +3932,9 @@ static time_t jembossctl_Datestr(const AjPStr s)
 
     tmp = ajStrNew();
     ajStrAssignS(&tmp,s);
-    p = (char*)ajStrGetPtr(tmp);
+
+    p = tmp->Ptr;
+
     while(*p)
     {
 	if(*p == '_' || *p==':')
@@ -3889,13 +4001,13 @@ static time_t jembossctl_Datestr(const AjPStr s)
 
 static int jembossctl_date(const void* str1, const void* str2)
 {
-    AjPStr *a;
-    AjPStr *b;
+    AjPStr a;
+    AjPStr b;
 
-    a = (AjPStr*)str1;
-    b = (AjPStr*)str2;
+    a = *(AjPStr const *)str1;
+    b = *(AjPStr const *)str2;
 
-    return (int)(jembossctl_Datestr(*b) - jembossctl_Datestr(*a));
+    return (int)(jembossctl_Datestr(b) - jembossctl_Datestr(a));
 }
 
 
@@ -3970,6 +4082,9 @@ static AjBool jembossctl_GetSeqsetFromUsa(const AjPStr thys, AjPSeqset *seq)
 #else
 #include <stdio.h>
 
+
+
+
 /* @header main ***************************************************************
 **
 ******************************************************************************/
