@@ -95,8 +95,8 @@ int main(int argc, char **argv)
     gapextend = ajAcdGetFloat("gapextend");
     align     = ajAcdGetAlign("outfile");
 
-    gapopen = ajRoundF(gapopen, 8);
-    gapextend = ajRoundF(gapextend, 8);
+    gapopen = ajRoundFloat(gapopen, 8);
+    gapextend = ajRoundFloat(gapextend, 8);
 
     AJCNEW(path, maxarr);
     AJCNEW(compass, maxarr);
@@ -112,8 +112,8 @@ int main(int argc, char **argv)
     m = ajStrNew();
     n = ajStrNew();
 
-    sub = ajMatrixfArray(matrix);
-    cvt = ajMatrixfCvt(matrix);
+    sub = ajMatrixfGetMatrix(matrix);
+    cvt = ajMatrixfGetCvt(matrix);
 
     begina = ajSeqGetBegin(a);
     beginb = ajSeqGetBegin(b);
