@@ -57,6 +57,8 @@ static AjBool remap_Ambiguous(const AjPStr str);
 static void remap_GetFrames(AjPStr const *framelist, AjBool *frames);
 
 
+
+
 /* @datastatic PValue *********************************************************
 **
 ** structure for counts and isoschizomers of a restriction enzyme hit
@@ -777,8 +779,11 @@ static void remap_NoCutList(AjPFile outfile, const AjPTable hittable,
     /* push all enzyme names without the required criteria onto nocutlist */
 
     enz = embPatRestrictNew();
-    while(embPatRestrictReadEntry(enz, enzfile))
+    while(!ajFileIsEof(enzfile))
     {
+        if(!embPatRestrictReadEntry(enz, enzfile))
+	    continue;
+
          /* 
 	 ** If user entered explicit enzyme list, then check to see if
 	 ** this is one of that explicit list 
@@ -1313,6 +1318,9 @@ static void remap_RestrictPreferred(const AjPList l, const AjPTable t)
     return; 
 }
 
+
+
+
 /* @funcstatic remap_Ambiguous  ***************************************
 **
 ** Tests whether there are ambiguity base codes in a string
@@ -1342,6 +1350,9 @@ static AjBool remap_Ambiguous(const AjPStr str)
     return ajFalse;
 }
 
+
+
+
 /* @funcstatic remap_GetFrames **********************************************
 **
 ** Converts the list of frame numbers into a boolean vector.
