@@ -210,14 +210,15 @@ int main(int argc, char **argv)
 			      &release, &methods, &defined))
 	    {
 		if(protein &&
-		   (ajStrMatchC(type, "P") || ajStrMatchC(type, "Protein")))
-		   showdbDBOut(outfile, nextdbname, type, id, qry, all,
-				 methods, defined,
-				 comment, release, html, dotype, doid,
-				 doqry, doall, domethod, dofields, dodefined,
-				 docomment, 
-				 dorelease, maxname,maxtype,  maxmethod,
-				 maxfield, maxdefined, maxrelease);
+		   (ajStrMatchC(type, "P") ||
+                    ajStrMatchCaseC(type, "Protein")))
+                    showdbDBOut(outfile, nextdbname, type, id, qry, all,
+                                methods, defined,
+                                comment, release, html, dotype, doid,
+                                doqry, doall, domethod, dofields, dodefined,
+                                docomment, 
+                                dorelease, maxname,maxtype,  maxmethod,
+                                maxfield, maxdefined, maxrelease);
 	    }
 	    else
 		ajFatal("The database '%S' does not exist", nextdbname);
@@ -234,15 +235,16 @@ int main(int argc, char **argv)
 			      &release, &methods, &defined))
 	    {
 		if( nucleic &&
-		   (ajStrMatchC(type, "N") || ajStrMatchC(type, "Nucleotide")))
+		   (ajStrMatchC(type, "N") ||
+                    ajStrPrefixCaseC(type, "Nucleotide")))
 		    showdbDBOut(outfile, nextdbname, type, id, qry, all,
-				 methods, defined,
-				 comment, release, html,
-				 dotype, doid,
-				 doqry, doall, domethod, dofields, dodefined,
-				 docomment, dorelease,
-				 maxname, maxtype, maxmethod,
-				 maxfield, maxdefined, maxrelease);
+                                methods, defined,
+                                comment, release, html,
+                                dotype, doid,
+                                doqry, doall, domethod, dofields, dodefined,
+                                docomment, dorelease,
+                                maxname, maxtype, maxmethod,
+                                maxfield, maxdefined, maxrelease);
 	    }
 	    else
 		ajFatal("The database '%S' does not exist", nextdbname);
@@ -271,6 +273,8 @@ int main(int argc, char **argv)
 }
 
 
+
+
 /* @funcstatic showdbDBWidth **************************************************
 **
 ** Update maximum width for variable length text
@@ -322,6 +326,9 @@ static void showdbDBWidth (const AjPStr dbname,
     return;
 }
 
+
+
+
 /* @funcstatic showdbDBHead ***************************************************
 **
 ** Output header for db information
@@ -478,6 +485,9 @@ static void showdbDBHead (AjPFile outfile, AjBool html, AjBool dotype,
     return;
 }
 
+
+
+
 /* @funcstatic showdbDBOut ****************************************************
 **
 ** Output db information
@@ -691,6 +701,8 @@ static void showdbGetFields(const AjPStr dbname, AjPStr* fields)
 }
 
 
+
+
 /* @funcstatic showdbDBSortDefined ********************************************
 **
 ** Compares the value of two strings for use in sorting (e.g. ajListSort)
