@@ -135,7 +135,9 @@ public class BuildJembossForm implements ActionListener
     attach(p2, fieldPane, appDescription);
 
     p2.add(fieldPane,BorderLayout.CENTER);
-    p2.setBackground(outSection.getBackground());
+
+    if(outSection!=null)
+        p2.setBackground(outSection.getBackground());
     
 // Help button
     ClassLoader cl = this.getClass().getClassLoader();
@@ -375,17 +377,20 @@ public class BuildJembossForm implements ActionListener
     outSection = null;
     inpSection = null;
 
-//  if(withSoap)
-//  {
       if(parseAcd.isBatchable() && 
          !parseAcd.getExpectedCPU().equalsIgnoreCase("low"))
         Jemboss.resultsManager.updateMode("batch");
       else
         Jemboss.resultsManager.updateMode("interactive");
-//  }
 
+      if((withSoap && BuildProgramMenu.serverSupportsPDF) ||
+              (!withSoap && mysettings.getEmbossHavePDF()))
+          graphics = new JComboBox( new String[]{ "PNG","PDF","SVG",
+          "Jemboss Graphics"} );
+      else
+          graphics = new JComboBox( new String[]{ "PNG","SVG",
+          "Jemboss Graphics"} );
 
-    graphics = new JComboBox( new String[]{ "PNG","Jemboss Graphics"} );
 
     for(int j=0;j<nsection;j++)
     {
@@ -469,7 +474,8 @@ public class BuildJembossForm implements ActionListener
         {
           if(batchStart)
           {
-            BatchSoapProcess bsp = new BatchSoapProcess(embossCommand,filesToMove,mysettings);
+            BatchSoapProcess bsp = new BatchSoapProcess(embossCommand,
+                    filesToMove, mysettings, commandA);
             bsp.setWithSoap(false);
             bsp.start();
             if (prfs.getBoolean(DISPLAY_JOB_SUBMITTED_MSG, true)){
@@ -511,12 +517,15 @@ public class BuildJembossForm implements ActionListener
           else
           {
               JembossServer js = new JembossServer(mysettings.getResultsHome());
-              js.setEmbossCommandA((String[])commandA.toArray(new String[commandA.size()]));
-              Vector result = js.run_prog(embossCommand, 
-                      mysettings.getCurrentMode(), filesToMove);
+              // standalone jemboss, no files to move
+              Vector filesToMovev = new Vector();
+              Vector result = js.run_prog_array(
+                      new Vector(commandA), 
+                      mysettings.getCurrentMode(), filesToMovev, "");
               Hashtable r = convert(result,false);
               try {
-                  resultSetFrame = new ShowResultSet(r,filesToMove,mysettings);
+                  resultSetFrame = new ShowResultSet(r,filesToMove,
+                          js.getProjectName(),mysettings);
               } catch (OutOfMemoryError e) {
                   result.clear();
                   filesToMove.clear();
@@ -528,8 +537,9 @@ public class BuildJembossForm implements ActionListener
       }
       else
       {
+        List commandA = new ArrayList();
         Hashtable filesToMove = new Hashtable();
-        String embossCommand = getCommand(filesToMove);
+        String embossCommand = getCommand(filesToMove, commandA);
 
         if(!embossCommand.equals("NOT OK"))
         {
@@ -541,23 +551,37 @@ public class BuildJembossForm implements ActionListener
           {
             if(batchStart)
             {
-              BatchSoapProcess bsp = new BatchSoapProcess(embossCommand,filesToMove,mysettings);
+              BatchSoapProcess bsp = new BatchSoapProcess(embossCommand,
+                      filesToMove, mysettings, commandA);
               bsp.start();
             }
             else
             {
-              JembossRun thisrun = new JembossRun(embossCommand,"",
-                                           filesToMove,mysettings);
-              resultSetFrame = new ShowResultSet(thisrun.hash(),filesToMove,mysettings);
+              JembossRun thisrun;
+              if(mysettings.getUseAuth())
+                thisrun = new JembossRun(embossCommand, "",filesToMove,
+                        mysettings);
+              else
+                thisrun = new JembossRun(commandA, "",filesToMove,mysettings);
+
+              resultSetFrame = new ShowResultSet(thisrun.hash(),filesToMove,
+                      mysettings);
             }
           }
           catch (JembossSoapException eae)
           {
+              if (mysettings.getUseAuth() == true)
+              {
             AuthPopup ap = new AuthPopup(mysettings,f);
             ap.setBottomPanel();
             ap.setSize(380,170);
             ap.pack();
             ap.setVisible(true);
+              }
+              else
+                  JOptionPane.showMessageDialog(f,eae.getMessage(),
+                          "Problem in executing server job",
+                          JOptionPane.ERROR_MESSAGE);
           }
         }
       }
@@ -594,7 +618,7 @@ public class BuildJembossForm implements ActionListener
       if(s.equals("msg"))
       {
         String msg = (String)vans.get(j+1);
-        if(msg.startsWith("Error"))
+        if(msg.indexOf("Error")!=-1 || msg.indexOf("error")!=-1)
           JOptionPane.showMessageDialog(null, msg, "alert",
                                 JOptionPane.ERROR_MESSAGE);
       }
@@ -824,11 +848,21 @@ public class BuildJembossForm implements ActionListener
         if(((String)graphics.getSelectedItem()).equals("PNG") )
         { 
           options = options.concat(" -" + val + " png");
-          optionsA.add("png");          
+          optionsA.add("png");
+        }
+        else if(((String)graphics.getSelectedItem()).equals("PDF") )
+        { 
+          options = options.concat(" -" + val + " pdf");
+          optionsA.add("pdf");
+        }
+        else if(((String)graphics.getSelectedItem()).equals("SVG") )
+        { 
+          options = options.concat(" -" + val + " svg");
+          optionsA.add("svg");
         }
         else {
           options = options.concat(" -" + val + " data");
-          optionsA.add("data");                    
+          optionsA.add("data");
         }
       }
       if ( att.startsWith("dirlist") || att.startsWith("featout") ||
@@ -839,7 +873,7 @@ public class BuildJembossForm implements ActionListener
         if(!(textf[h].getText()).equals("") && textf[h].isVisible()
                                             && textf[h].isEnabled()) 
         {
-          options = options.concat(" -" + val + " " + textf[h].getText());
+          options = options.concat(" -" + val + " \"" + textf[h].getText())+"\"";
           optionsA.add("-" + val);
           optionsA.add(textf[h].getText());
 
@@ -868,7 +902,8 @@ public class BuildJembossForm implements ActionListener
         
         if(textFields[0].getText() != null && !textFields[0].getText().trim().equals(""))
         {
-          options = options.concat(" -" + val + " " + textFields[0].getText());
+          options = options.concat(" -" + val + " \"" +
+                  textFields[0].getText()+ "\"");
           optionsA.add("-" + val);
           optionsA.add(textFields[0].getText());
         }
@@ -1262,16 +1297,15 @@ public class BuildJembossForm implements ActionListener
 
 /**
 *
-* Get the command line for the Standalone version.
-* @param Hashtable of the files to be transferrred
+* Get the command line for the standalone as well as the client jemboss
+* @param Hashtable of the files to be transferred
 * @return String command line to use
 *
 */
   private String getCommand(Hashtable filesToMove, List commandA)
   {
-	  String embossBin = mysettings.getEmbossBin();
 	  String command = applName;
-	  commandA.add(embossBin +(embossBin.endsWith(File.separator)?"":File.separator)+command);
+	  commandA.add(command);
 	  int numofFields = parseAcd.getNumofFields();
 
 	  String options = checkParameters(parseAcd, numofFields, filesToMove, commandA);
@@ -1279,7 +1313,12 @@ public class BuildJembossForm implements ActionListener
 	  if(options.equals("NOT OK"))
 		  command = "NOT OK";
 	  else {
-		  command = command.concat(options + " -auto");
+	      for (int i=0; i<commandA.size();i++){
+	          String s = (String)commandA.get(i);
+	          if(s.equals("stdout"))
+	          commandA.set(i, "stdoutfile");
+	      }
+		  command = command.concat(options.replaceAll("\"stdout\"", "stdoutfile") + " -auto");
 		  commandA.add("-auto");
 	  }
 
@@ -1287,29 +1326,6 @@ public class BuildJembossForm implements ActionListener
   }
 
 
-/**
-*
-* Get the command line for the SOAP version.
-* @param Hashtable of the files to be transferrred
-* @return String command line to use
-*
-*/
-  private String getCommand(Hashtable filesToMove)
-  {
-	  String command = applName;
-	  int numofFields = parseAcd.getNumofFields();
-
-	  String options = checkParameters(parseAcd, numofFields, filesToMove, new ArrayList());
-
-	  if(options.equals("NOT OK"))
-		  command = "NOT OK";
-	  else {
-		  command = command.concat(options + " -auto");
-	  }
-
-	  return command;
-  }
-
 
 /**
 *
@@ -1326,16 +1342,18 @@ public class BuildJembossForm implements ActionListener
   public class BatchSoapProcess extends Thread
   {
     private String embossCommand;
+    List command;
     private Hashtable filesToMove;
     private JembossParams mysettings;
     private boolean withSoap = true;
 
     public BatchSoapProcess(String embossCommand, Hashtable filesToMove,
-                            JembossParams mysettings)
+                            JembossParams mysettings, List command)
     {
       this.embossCommand = embossCommand;
       this.filesToMove   = filesToMove;
       this.mysettings    = mysettings;
+      this.command = command;
     }
 
     public void setWithSoap(boolean withSoap)
@@ -1364,15 +1382,23 @@ public class BuildJembossForm implements ActionListener
         final JembossProcess er;
         if(withSoap)
         {
-          JembossRun thisrun = new JembossRun(embossCommand,"",
-                                       filesToMove,mysettings);
+            JembossRun thisrun;
+            if (mysettings.getUseAuth() == true)
+                thisrun = new JembossRun(embossCommand,"",filesToMove,
+                        mysettings);
+            else
+                thisrun = new JembossRun(command,"",filesToMove,mysettings);
           er = new JembossProcess((String)thisrun.get("jobid"));
         }
         else
         {
           JembossServer js = new JembossServer(mysettings.getResultsHome());
-          Vector result = js.run_prog(embossCommand,mysettings.getCurrentMode(),
-                                        filesToMove);
+          // standalone jemboss, no files to move
+          Vector filesToMovev = new Vector();
+          Vector result = js.run_prog_array(
+                  new Vector(command),
+                  mysettings.getCurrentMode(),
+                                        filesToMovev, "");
           Hashtable resultHash = convert(result, false);
           er = new JembossProcess((String)resultHash.get("jobid"));
         }
