@@ -59,6 +59,8 @@ static AjPRegexp dbiRegEntryIdSort    = NULL;
 static AjPRegexp dbiRegDate           = NULL;
 
 
+
+
 /* @datastatic DbiOField ******************************************************
 **
 ** Database index field names and index filenames
@@ -90,6 +92,8 @@ static DbiOField fieldDef[] =
 static const char* dbiFieldFile(const AjPStr fieldname);
 
 
+
+
 /* @func embDbiFieldNew *******************************************************
 **
 ** Constructor for field token structures.
@@ -629,15 +633,17 @@ void embDbiRmFile(const AjPStr dbname, const char* ext, ajuint nfiles,
 
     if(nfiles)
     {
-	ajFmtPrintS(&dbiCmdStr, "rm ");
-
 	for(i=1; i<= nfiles; i++)
-	    ajFmtPrintAppS(&dbiCmdStr, "%S%03d.%s ", dbname, i, ext);
+        {
+	    ajFmtPrintS(&dbiCmdStr, "%S%03d.%s", dbname, i, ext);
+            ajSysCommandRemoveS(dbiCmdStr);
+        }
     }
     else
-	ajFmtPrintS(&dbiCmdStr, "rm %S.%s", dbname, ext);
-
-    embDbiSysCmd(dbiCmdStr);
+    {
+	ajFmtPrintS(&dbiCmdStr, "%S.%s", dbname, ext);
+        ajSysCommandRemoveS(dbiCmdStr);
+    }
 
     return;
 
@@ -689,16 +695,16 @@ void embDbiRmFileI(const AjPStr dbname, const char* ext, ajuint ifile,
     if(!cleanup)
 	return;
 
-    ajFmtPrintS(&dbiCmdStr, "rm %S%03d.%s ", dbname, ifile, ext);
+    ajFmtPrintS(&dbiCmdStr, "%S%03d.%s", dbname, ifile, ext);
 
-    embDbiSysCmd(dbiCmdStr);
+    ajSysCommandRemoveS(dbiCmdStr);
 #else
     static AjPStr filestr = NULL;
     
     if(!cleanup)
 	return;
     
-    ajFmtPrintS (&filestr, "%S%03d.%s ", dbname, ifile, ext);
+    ajFmtPrintS (&filestr, "%S%03d.%s", dbname, ifile, ext);
     DeleteFile(ajStrGetPtr(filestr));
     ajDebug("Deleting file %S\n", filestr);
 #endif	/* WIN32 */
@@ -756,9 +762,11 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
     double td;
     
 #ifndef WIN32
-    static const char *prog = "env LC_ALL=C sort";
+    static const char *prog = "sort";
+
+    dir = ajStrNewC(prog);
+    ajSysFileWhich(&dir);
 
-    dir = ajStrNewC("");
 #else
     static const char *prog = "sort.exe";
     
@@ -773,6 +781,7 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
 
     dir = ajStrNewC(sortProgDir);
     ajStrAppendC(&dir,SLASH_STRING);
+    ajStrAppendC(&dir,prog);
 #endif
 
 
@@ -780,17 +789,17 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
     {
 	for(i=1; i<=nfiles; i++)
 	{
-	    ajFmtPrintS(&dbiInFname, "%S%03d.%s ", dbname, i, ext1);
+	    ajFmtPrintS(&dbiInFname, "%S%03d.%s", dbname, i, ext1);
 	    ajFmtPrintS(&dbiOutFname, "%S%03d.%s.srt", dbname, i, ext1);
 
 	    if(sortopt)
-		ajFmtPrintS(&dbiCmdStr, "%S%s -o %S %S %S",
-			    dir,prog,dbiOutFname,sortopt,dbiInFname);
+		ajFmtPrintS(&dbiCmdStr, "%S -o %S %S %S",
+			    dir,dbiOutFname,sortopt,dbiInFname);
 	    else
-		ajFmtPrintS(&dbiCmdStr, "%S%s -o %S %S",
-			    dir,prog,dbiOutFname,dbiInFname);
+		ajFmtPrintS(&dbiCmdStr, "%S -o %S %S",
+			    dir,dbiOutFname,dbiInFname);
 
-	    embDbiSysCmd(dbiCmdStr);
+	    ajSysExecLocaleC(ajStrGetPtr(dbiCmdStr), "C");
 	    embDbiRmFileI(dbname, ext1, i, cleanup);
 	}
 
@@ -803,14 +812,14 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
 
 	if(nsplit < 2)		/* up to 3 source files */
 	{
-            ajFmtPrintS(&dbiCmdStr, "%S%s -m -o %S.%s %S",
-                        dir,prog,dbname,ext2,sortopt);
+            ajFmtPrintS(&dbiCmdStr, "%S -m -o %S.%s %S",
+                        dir,dbname,ext2,sortopt);
 
             for(i=1; i<=nfiles; i++)
                 ajFmtPrintAppS(&dbiCmdStr, " %S%03d.%s.srt", dbname, i, ext1);
 
-            embDbiSysCmd(dbiCmdStr);
-            ajFmtPrintS(&dbiSortExt, "%s.srt ", ext1);
+            ajSysExecLocaleC(ajStrGetPtr(dbiCmdStr), "C");
+            ajFmtPrintS(&dbiSortExt, "%s.srt", ext1);
 
             for(i=1; i<=nfiles; i++)
                 embDbiRmFileI(dbname, ajStrGetPtr(dbiSortExt), i, cleanup);
@@ -818,8 +827,8 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
 	}
 	else
 	{
-            ajFmtPrintS(&dbiCmdStr2, "%S%s -m -o %S.%s %S",
-                        dir,prog,dbname,ext2,sortopt);
+            ajFmtPrintS(&dbiCmdStr2, "%S -m -o %S.%s %S",
+                        dir,dbname,ext2,sortopt);
             isplit = 0;
 
             for(i=1; i<=nfiles; i+=nsplit)
@@ -830,16 +839,16 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
 
                 /* Now we make that .mrg1 file */
 
-                ajFmtPrintS(&dbiCmdStr, "%S%s -m -o %S%03d.%s.mrg1 %S",
-                            dir,prog,dbname,isplit,ext2,sortopt);
+                ajFmtPrintS(&dbiCmdStr, "%S -m -o %S%03d.%s.mrg1 %S",
+                            dir,dbname,isplit,ext2,sortopt);
 
                 for(j=0; j<nsplit; j++)
                     if((i+j) <= nfiles)
                         ajFmtPrintAppS(&dbiCmdStr, " %S%03d.%s.srt",
                                        dbname, i+j, ext1);
 
-                embDbiSysCmd(dbiCmdStr);
-                ajFmtPrintS(&dbiSortExt, "%s.srt ", ext1);
+                ajSysExecLocaleC(ajStrGetPtr(dbiCmdStr),"C");
+                ajFmtPrintS(&dbiSortExt, "%s.srt", ext1);
 
                 for(j=0; j<nsplit; j++)
                     if((i+j) <= nfiles)
@@ -847,7 +856,7 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
                                       cleanup);
             }
 
-            embDbiSysCmd(dbiCmdStr2);
+            ajSysExecLocaleC(ajStrGetPtr(dbiCmdStr2), "C");
             ajFmtPrintS(&dbiSortExt, "%s.mrg1", ext2);
 
             for(j=1; j<=isplit; j++)
@@ -856,12 +865,12 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
     }
     else
     {
-	ajFmtPrintS(&dbiInFname, "%S.%s ", dbname, ext1);
+	ajFmtPrintS(&dbiInFname, "%S.%s", dbname, ext1);
 	ajFmtPrintS(&dbiOutFname, "%S.%s", dbname, ext2);
-	ajFmtPrintS(&dbiCmdStr, "%S%s -o %S %S %S",
-		    dir,prog,dbiOutFname,sortopt,dbiInFname);
+	ajFmtPrintS(&dbiCmdStr, "%S -o %S %S %S",
+		    dir,dbiOutFname,sortopt,dbiInFname);
 
-	embDbiSysCmd(dbiCmdStr);
+	ajSysExecLocaleC(ajStrGetPtr(dbiCmdStr), "C");
 	embDbiRmFile(dbname, ext1, 0, cleanup);
     }
 
@@ -873,71 +882,6 @@ void embDbiSortFile(const AjPStr dbname, const char* ext1, const char* ext2,
 
 
 
-/* @func embDbiSysCmd *********************************************************
-**
-** Fork a system command
-**
-** @param [r] cmdstr [const AjPStr] Command line
-** @return [void]
-** @@
-******************************************************************************/
-
-void embDbiSysCmd(const AjPStr cmdstr)
-{
-#ifndef WIN32
-    char** arglist = NULL;
-    char* pgm;
-    pid_t pid;
-    pid_t retval;
-    ajint status;
-
-    ajDebug("forking '%S'", cmdstr);
-    ajSysArglistBuild(cmdstr, &pgm, &arglist);
-
-    pid = fork();
-    if(pid==-1)
-	ajFatal("System fork failed");
-
-
-    if(!pid)
-    {
-	execvp(pgm, arglist);
-	ajExitAbort();			/* just in case */
-    }
-
-    while((retval=waitpid(pid,&status,0))!=pid)
-    {
-	if(retval == -1)
-	    if(errno != EINTR)
-		break;
-    }
-
-    ajSysArglistFree(&arglist);
-    ajCharDel(&pgm);
-
-#else
-    PROCESS_INFORMATION procInfo;
-    STARTUPINFO startInfo;
-    
-    ajDebug ("Launching process '%S'\n", cmdstr);
-    
-    ZeroMemory(&startInfo, sizeof(startInfo));
-    startInfo.cb = sizeof(startInfo);
-    
-    if (!CreateProcess(NULL, (char *)ajStrGetPtr(cmdstr), NULL, NULL, FALSE,
-		       CREATE_NO_WINDOW, NULL, NULL, &startInfo, &procInfo))
-	ajFatal("CreateProcess failed");
-
-    WaitForSingleObject(procInfo.hProcess, INFINITE);
-
-#endif	/* WIN32 */
-
-    return;
-}
-
-
-
-
 /* @func embDbiHeaderSize *****************************************************
 **
 ** Updates the file header for an index file to include the correct file size.
@@ -1501,7 +1445,7 @@ ajuint embDbiMemWriteEntry(AjPFile entFile, ajuint maxidlen,
 
 	if(ajStrMatchCaseC(dbiIdStr, entry->entry))
 	{
-	    ajErr("Duplicate ID found: '%S'. ", dbiIdStr);
+	    ajErr("Duplicate ID found: '%S'", dbiIdStr);
 	    continue;
 	}
 
