@@ -4,9 +4,9 @@
 # DONE
 ##########################
 # Timeout (TI line to set) default 60secs, diffseq needs more
-# Preprocess (PP line) command
-# Postprocess (QQ line) command - e.g. testing database builds, reusing output
-# EMBOSS_RC variable to read an extra .embossrc file (for new test dbs)
+# Pre-process (PP line) command
+# Post-process (QQ line) command - e.g. testing database builds, reusing output
+# EMBOSS_RC variable to read an extra .embossrc file (for new test databases)
 #
 ##########################
 # THINGS TO DO
@@ -24,15 +24,15 @@
 # ER error return code
 # ## Comment (required double #)
 # CC Comment (used in commenting on failed tests, e.g. "Requires SRS"
-# DL success or all or keep - whether to delete the files afterways
+# DL success or all or keep - whether to delete the files afterwards
 # IN Line(s) of standard input
 # FI File name (stdout and stderr assumed to exist and be empty unless stated)
 # FK Keystrokes output File name (non-text)
 # FP File pattern - /regexp/ to be found. Optional count to check exact number.
 # FZ [<=>]number File size test. Implicit test for zero size stdout/stderr
 #                unless stated
-# FC [<=>]number File linecount test
-# UC Comment (used un documenting the usage)
+# FC [<=>]number File line count test
+# UC Comment (used in documenting the usage)
 # IC Comment (used in documenting the input files)
 # OC Comment (used in documenting the output files)
 # RQ Requires (e.g. SRS for tests that need a local getz working)
@@ -52,7 +52,7 @@
 
 sub usage () {
   print STDERR "Usage:\n";
-  print STDERR "  qatest.pl [-kk | -ks | -ka] [-t=60] [-wild] [-mcheck] [testnames...]\n";
+  print STDERR "  qatest.pl [-kk | -ks | -ka] [-t=60] [-wild] [-mcheck] [-noembassy] [-embassy=package] [testnames...]\n";
   print STDERR "            defaults: -kk -t=60\n";
 }
 
@@ -141,7 +141,7 @@ sub runtest ($) {
     elsif ($line =~ /^AP\s+(\S+)/) {
 	$testapp = $1;
 	$apcount{$testapp}++;
-	if (!defined($tfm{$testapp})) {
+	if (!$simple && !defined($tfm{$testapp})) {
 	    $tfm{$testapp}=0;
 	    $dtop = "../../doc/programs/";
 	    if (-e "$dtop/html/$testapp.html") {$tfm{$testapp}++}
@@ -735,7 +735,7 @@ $testappname=0;
 $misshtml=0;
 $misstext=0;
 $misssf=0;
-%without = ();
+%without = ("srs" => 1);
 %dotest = ();
 %tfm = ();
 %sf = ();
@@ -748,7 +748,19 @@ $testwild = "*";
 $doembassy=1;
 $docheck=1;
 $qatestfile = "../qatest.dat";
+
 $acddir=  "../../emboss/acd";
+$simple=0;
+
+open (VERSION, "embossversion -full -filter|") ||
+    die "Cannot run embossversion";
+while (<VERSION>){
+    if(/BaseDirectory: (\S+)/) {
+	$acddir = $1;
+	$qatestfile = "$acddir"."test/qatest.dat";
+    }
+}
+close VERSION;
 
 foreach $test (@ARGV) {
   if ($test =~ /^-(.*)/) {
@@ -759,6 +771,7 @@ foreach $test (@ARGV) {
     elsif ($opt eq "ka") {$defdelete="all"}
     elsif ($opt eq "noembassy") {$doembassy=0}
     elsif ($opt eq "nocheck") {$docheck=0}
+    elsif ($opt eq "simple") {$simple=1}
     elsif ($opt eq "wild") {
 	$dowild=1;
 	if(defined($testname)) {
@@ -767,10 +780,12 @@ foreach $test (@ARGV) {
     }
     elsif ($opt eq "mcheck") {$domcheck="MALLOC_CHECK_=3;export MALLOC_CHECK_;"}
     elsif ($opt =~ /without=(\S+)/) {$without{$1}=1}
+    elsif ($opt =~ /with=(\S+)/) {undef($without{$1})}
     elsif ($opt =~ /t=([0-9]+)/) {$timeoutdef=int($1)}
     elsif ($opt =~ /logfile=(\S+)/) {$logfile=">$1"} # append to logfile
     elsif ($opt =~ /testfile=(\S+)/) {$qatestfile="$1"}
     elsif ($opt =~ /acd=(\S+)/) {$acddir="$1"}
+    elsif ($opt =~ /embassy=(\S+)/) {$embassyonly="$1"}
     else {print STDERR "+++ unknown option '$opt'\n"; usage()}
   }
   else {
@@ -849,7 +864,7 @@ if (!$numtests) {
 
   undef @acdfiles;
 
-  open (WOSSNAME, "export -n EMBOSS_ACDCOMMANDLINE;wossname -alpha -auto|") || die "Cannot run wossname";
+  open (WOSSNAME, "unset EMBOSS_ACDCOMMANDLINE;wossname -alpha -auto|") || die "Cannot run wossname";
   while (<WOSSNAME>) {
     if (/^[a-z]\S+/) {
       $app = $&;
@@ -885,7 +900,8 @@ while (<IN>) {
     $ischeck = 0;
     $isembassy = 0;
   }
-  if (/^AA\s+/) {$isembassy = 1}
+  if (/^AA\s+(\S+)/) {$isembassy = 1}
+  if (/^AB\s+(\S+)/) {$embassypack = $1}
   if (/^AQ\s+/) {$ischeck = 1}
   $testdef .= $_;
 
@@ -894,7 +910,11 @@ while (<IN>) {
   if (/^\/\//) {
     if (($numtests > 0) && !$dowild && !$dotest{$id}) {next}
     if (($numtests > 0) && $dowild && $id !~ /$testwild/) {next}
-    if($isembassy && !$doembassy) {next}
+    if($isembassy){
+      if(!$doembassy) {next}
+      if(defined($embassyonly) && ($embassyonly ne $embassypack)){$testappname=0;next}
+    }
+    elsif(defined($embassyonly)){$testappname=0;next}
     if($ischeck && !$docheck) {next}
     $result = runtest ($testdef);
     $tcount++;
@@ -1011,10 +1031,12 @@ foreach $x (sort(keys(%packfail))) {
     }
 }
 print STDERR "Tests total: $totall pass: $tpass fail: $tfail\n";
-print STDERR "Skipped: $totskip check: $skipcheck embassy: $skipembassy requirements: $skipreq\n";
+if(!$simple) {
+    print STDERR "Skipped: $totskip check: $skipcheck embassy: $skipembassy requirements: $skipreq\n";
 
-print STDERR "No tests: $tnotest\n";
-print STDERR "Missing documentation html: $misshtml text: $misstext sourceforge: $misssf\n";
+    print STDERR "No tests: $tnotest\n";
+    print STDERR "Missing documentation html: $misshtml text: $misstext sourceforge: $misssf\n";
+}
 print STDERR "Time: $alltime seconds\n";
 print LOG "Time: $alltime seconds\n";
 
